@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -134,6 +134,7 @@ Usage(int expert)
     printf("    -%sv%s  use ML variance weighting (no correlations)                         \n", tc_GREEN, tc_NC);
 
     printf("\n Input/output options: \n");
+    printf("    --amber  for reading AMBER8 formatted PDB files                             \n");
     printf("    -A  sequence alignment file to use as a guide (CLUSTAL or A2M format)       \n");
     printf("    -E  print expert options                                                    \n");
     printf("    -F  print FASTA files of the sequences in PDB files and quit                \n");
@@ -154,7 +155,16 @@ Usage(int expert)
 
     printf("\n");
     printf(" Citations: \n");
-    printf("   Douglas L. Theobald and Deborah S. Wuttke (2006) \n");
+    printf("   Douglas L. Theobald and Phillip A. Steindel (2012) \n");
+    printf("   \"Optimal simultaneous superpositioning of multiple structures with missing\n");
+    printf("   data.\"\n");
+    printf("   Bioinformatics 28(15):1972-1979\n");
+    printf("\n");
+    printf("   Douglas L. Theobald and Deborah S. Wuttke (2008) \n");
+    printf("   \"Accurate structural correlations from maximum likelihood superpositions.\"\n");
+    printf("   PLOS Computational Biology, 4(2):e43\n");
+    printf("\n");
+/*    printf("   Douglas L. Theobald and Deborah S. Wuttke (2006) \n");
     printf("   \"Empirical Bayes models for regularizing maximum likelihood estimation in\n");
     printf("   the matrix Gaussian Procrustes problem.\"\n");
     printf("   PNAS 103(49):18521-18527\n");
@@ -163,11 +173,7 @@ Usage(int expert)
     printf("   \"THESEUS: Maximum likelihood superpositioning and analysis of molecular\n");
     printf("   structures.\"\n");
     printf("   Bioinformatics 22(17):2171-2172\n");
-    printf("\n");
-    printf("   Douglas L. Theobald and Deborah S. Wuttke (2008) \n");
-    printf("   \"Accurate structural correlations from maximum likelihood superpositions.\"\n");
-    printf("   PLOS Computational Biology, 4(2):e43\n");
-    printf("\n");
+    printf("\n"); */
     printf("   http://www.theseus3d.org/\n");
     printf("   Compiled with GSL version %s\n", GSL_VERSION);
     //printf("   Compiled with LAPACK version %d.%d.%d\n", vers_major, vers_minor, vers_patch);
