@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -755,11 +755,16 @@ GibbsMean(CdsArray *cdsA, const gsl_rng *r2)
         avez[i] += gsl_ran_gaussian(r2, mvar);
     }
 
+
     CenMass(cdsA->avecds);
+
+/* 
     ApplyCenterIp(cdsA->avecds);
 
     for (i = 0; i < cnum; ++i)
         NegTransCdsIp(cdsA->cds[i], cdsA->avecds->center);
+ */
+
 }
 
 
@@ -767,7 +772,7 @@ static void
 GibbsMeanDiag(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
-    Cds         *avecds = cdsA->avecds;
+    Cds            *avecds = cdsA->avecds;
     double         *avex = avecds->x,
                    *avey = avecds->y,
                    *avez = avecds->z;
@@ -787,10 +792,18 @@ GibbsMeanDiag(CdsArray *cdsA, const gsl_rng *r2)
     }
 
     CenMassWtIp(avecds, cdsA->w);
+
+    printf("\ntrans: % f % f % f",
+           cdsA->avecds->center[0], cdsA->avecds->center[1], cdsA->avecds->center[2]);
+    fflush(NULL);
+
+/* 
     ApplyCenterIp(avecds);
 
     for (i = 0; i < cnum; ++i)
         NegTransCdsIp(cdsA->cds[i], cdsA->avecds->center);
+ */
+
 
 //    printf("\nmean trans[%d]: % f % f % f", i+1, 
 //           avecds->center[0], avecds->center[1], avecds->center[2]);
@@ -802,10 +815,10 @@ static void
 GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 {
     int             i;
-    Cds         *avecds = cdsA->avecds;
+//    Cds         *avecds = cdsA->avecds;
 //    const int       vlen = cdsA->vlen;
     const int       cnum = cdsA->cnum;
-    char            filename[256];
+    char            filename[256], avename[256];
 
 /* 
     for (i = 0; i < vlen; ++i)
@@ -818,12 +831,15 @@ GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 //     CenMass(avecds);
 //     ApplyCenterIp(avecds);
 
+/* 
     CalcCdsPrincAxesGibbs(avecds, avecds->matrix, cdsA->w);
     Mat3TransposeIp(avecds->matrix);
     RotateCdsIp(avecds, (const double **) avecds->matrix);
 
     for (i = 0; i < cnum; ++i)
         RotateCdsIp(cdsA->cds[i], (const double **) avecds->matrix);
+ */
+
 
     double sum = 0.0;
 
@@ -839,6 +855,8 @@ GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 /*     printf("\nWriting %s", filename); */
 /*     fflush(NULL); */
     WriteTheseusCdsModelFile(cdsA, filename);
+    sprintf(avename, "%s%05d.pdb", "gibbs_ave_", iter);
+    WriteAveCds(cdsA, avename);
 
     for (i = 0; i < cnum; ++i)
         ScaleCds(cdsA->cds[i], sum);
@@ -850,11 +868,11 @@ GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 static void
 GibbsMeanDiagWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 {
-    int             i;
-    Cds         *avecds = cdsA->avecds;
+    //int             i;
+    //Cds         *avecds = cdsA->avecds;
     //const int       vlen = cdsA->vlen;
-    const int       cnum = cdsA->cnum;
-    char            filename[256];
+    //const int       cnum = cdsA->cnum;
+    char            filename[256], avename[256];
 
     //AveCdsGibbs(cdsA);
     GibbsMeanDiag(cdsA, r2);
@@ -866,12 +884,15 @@ GibbsMeanDiagWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 //     CenMassWtIp(avecds, cdsA->w);
 //     ApplyCenterIp(avecds);
 
+/* 
     CalcCdsPrincAxesGibbs(avecds, avecds->matrix, cdsA->w);
     Mat3TransposeIp(avecds->matrix);
     RotateCdsIp(avecds, (const double **) avecds->matrix);
 
     for (i = 0; i < cnum; ++i)
         RotateCdsIp(cdsA->cds[i], (const double **) avecds->matrix);
+ */
+
 
 //     for (i = 0; i < vlen; ++i)
 //         cdsA->w[i] = 1.0 / cdsA->var[i];
@@ -880,19 +901,33 @@ GibbsMeanDiagWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 /*     printf("\nWriting %s", filename); */
 /*     fflush(NULL); */
     WriteTheseusCdsModelFile(cdsA, filename);
+    sprintf(avename, "%s%05d.pdb", "gibbs_ave_", iter);
+    WriteAveCds(cdsA, avename);
 
     GibbsMeanDiag(cdsA, r2);
 }
 
 
+void
+ModCenMass(Cds *cdsi, double *avecen)
+{
+    cdsi->center[0] -= avecen[0];
+    cdsi->center[1] -= avecen[1];
+    cdsi->center[2] -= avecen[2];
+}
+
+
 static void
 GibbsTrans(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          var = cdsA->stats->var;
-    double          tvar = sqrt(var / vlen), tvarbeta;
-    Cds         *cdsi = NULL;
+    double          tvar, tvarbeta;
+    //double          newcen[3];
+    Cds            *cdsi = NULL;
+
+    tvar = sqrt(var / vlen);
 
 /*     printf("\ntvar: % e", tvar); */
 /*     fflush(NULL); */
@@ -901,6 +936,8 @@ GibbsTrans(CdsArray *cdsA, const gsl_rng *r2)
     {
         cdsi = cdsA->cds[i];
         CenMass(cdsi);
+        //InvRotVec(&newcen[0], cdsA->avecds->center, cdsi->matrix);
+        //ModCenMass(cdsi, &newcen[0]);
 
 /*         printf("\n  trans[%d]", i+1); */
 /*         printf("\nB trans[%d]: % f % f % f", i+1,  */
@@ -916,7 +953,7 @@ GibbsTrans(CdsArray *cdsA, const gsl_rng *r2)
 /*                cdsA->cds[i]->center[0], cdsA->cds[i]->center[1], cdsA->cds[i]->center[2]); */
 /*         fflush(NULL); */
 
-         ApplyCenterIp(cdsi);
+        ApplyCenterIp(cdsi);
     }
 }
 
@@ -927,6 +964,7 @@ GibbsTransDiag(CdsArray *cdsA, const gsl_rng *r2)
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          tvar, invtr, tvarbeta;
+    //double          newcen[3];
     Cds            *cdsi = NULL;
 
     invtr = 0.0;
@@ -944,12 +982,15 @@ GibbsTransDiag(CdsArray *cdsA, const gsl_rng *r2)
     {
         cdsi = cdsA->cds[i];
         CenMassWtIp(cdsi, cdsA->w);
+        //InvRotVec(&newcen[0], cdsA->avecds->center, cdsi->matrix);
+        //ModCenMass(cdsi, &newcen[0]);
 
 /*         printf("\n  trans[%d]", i+1); */
 /*         printf("\nB trans[%d]: % f % f % f", i+1,  */
 /*                cdsi->center[0], cdsi->center[1], cdsi->center[2]); */
 
-        tvarbeta = tvar/cdsi->scale;
+        //tvarbeta = tvar/cdsi->scale;
+        tvarbeta = tvar;
 
         cdsi->center[0] += gsl_ran_gaussian(r2, tvarbeta);
         cdsi->center[1] += gsl_ran_gaussian(r2, tvarbeta);
@@ -1106,7 +1147,7 @@ GibbsMetRot(CdsArray *cdsA, double **theta, const gsl_rng *r2)
                                /* I simply offet the structures by a "location parameter". */
                                /* I do the same for the translations. */
                                /* We can't do this if the chains are run out of place */
-            
+
 /*         printf("\n\n****************\nstructure: %d", i+1); */
 /*         printf("\nF:"); */
 /*         Mat3Print(F); */
@@ -1797,7 +1838,7 @@ GibbsMet(CdsArray *cdsA)
     printf("~Ex: % e\n", 1.0+(gamma/sqrt(phi)));
     printf("~Ex_dlt: % e\n", sqrt(n/phi));
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     double          starttime, endtime;
     double          exitloop;
 
@@ -1816,7 +1857,7 @@ GibbsMet(CdsArray *cdsA)
     }
 
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     exitloop = (double) (endtime - starttime) / 0.001;
 
@@ -1825,16 +1866,17 @@ GibbsMet(CdsArray *cdsA)
 #endif
 
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     starttime = seconds();
 #endif
+
 if (0)
     for (i = 0; i < samples; ++i)
     {
         fprintf(rejfp, "%e\n", scale_rejection(n, gamma, phi, r2));
     }
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     exitloop = (double) (endtime - starttime) / 0.001;
 
