@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -538,21 +538,21 @@ CalcRotations(CdsArray *cdsA)
 
                 if (cdsA->algo->pu == 1)
                 {
-					double **qcpcds = MatAlloc(3, cds[i]->vlen);
-					double **qcptcds = MatAlloc(3, cds[i]->vlen);
-					size_t len = cds[i]->vlen * sizeof(double);
-					memcpy(qcpcds[0], cds[i]->x, len);
-					memcpy(qcpcds[1], cds[i]->y, len);
-					memcpy(qcpcds[2], cds[i]->z, len);
-					memcpy(qcptcds[0], tcds->x, len);
-					memcpy(qcptcds[1], tcds->y, len);
-					memcpy(qcptcds[2], tcds->z, len);
-					deviation = CalcRMSDRotationalMatrix(qcpcds, qcptcds, cds[i]->vlen, &cds[i]->matrix[0][0], NULL);
-					deviation = deviation * deviation * cds[i]->vlen;
-					//printf("\nqcp deviation: %g", deviation);
-					//MatPrint(cds[i]->matrix, 3);
-					MatDestroy(&qcpcds);
-					MatDestroy(&qcptcds);
+                    double **qcpcds = MatAlloc(3, cds[i]->vlen);
+                    double **qcptcds = MatAlloc(3, cds[i]->vlen);
+                    size_t len = cds[i]->vlen * sizeof(double);
+                    memcpy(qcpcds[0], cds[i]->x, len);
+                    memcpy(qcpcds[1], cds[i]->y, len);
+                    memcpy(qcpcds[2], cds[i]->z, len);
+                    memcpy(qcptcds[0], tcds->x, len);
+                    memcpy(qcptcds[1], tcds->y, len);
+                    memcpy(qcptcds[2], tcds->z, len);
+                    deviation = CalcRMSDRotationalMatrix(qcpcds, qcptcds, cds[i]->vlen, &cds[i]->matrix[0][0], NULL);
+                    deviation = deviation * deviation * cds[i]->vlen;
+                    //printf("\nqcp deviation: %g", deviation);
+                    //MatPrint(cds[i]->matrix, 3);
+                    MatDestroy(&qcpcds);
+                    MatDestroy(&qcptcds);
                 }
                 else
                 {
@@ -563,16 +563,16 @@ CalcRotations(CdsArray *cdsA)
 /*                                        cdsA->tmpmat3b, */
 /*                                        cdsA->tmpmat3c, */
 /*                                        cdsA->tmpvec3a); */
- 
-						deviation = ProcGSLSVDvan(cds[i],
-												  tcds,
-												  cds[i]->matrix,
-												  cdsA->tmpmat3a,
-												  cdsA->tmpmat3b,
-												  cdsA->tmpmat3c,
-												  cdsA->tmpvec3a);
-												  //printf("\nSVD deviation: %g", deviation);
-												  //MatPrint(cds[i]->matrix, 3);
+
+                        deviation = ProcGSLSVDvan(cds[i],
+                                                  tcds,
+                                                  cds[i]->matrix,
+                                                  cdsA->tmpmat3a,
+                                                  cdsA->tmpmat3b,
+                                                  cdsA->tmpmat3c,
+                                                  cdsA->tmpvec3a);
+                                                  //printf("\nSVD deviation: %g", deviation);
+                                                  //MatPrint(cds[i]->matrix, 3);
                 }
 
                 /* find global rmsd and average cds (both held in structure) */
@@ -586,7 +586,7 @@ CalcRotations(CdsArray *cdsA)
 }
 
 
-/* This is the classic iterative (not eigendecomp) solution given by Gower 1975 and in 
+/* This is the classic iterative (not eigendecomp) solution given by Gower 1975 and in
    Gower and Dijksterhuis 2004, Ch 9, page 113, Eqn 9.21 */
 double
 CalcScaleFactors(CdsArray *cdsA)
@@ -690,24 +690,24 @@ ConstrainCovMat(CdsArray *cdsA)
     {
         cdsj = (Cds *) cds[j];
 
-		for (i = 0; i < vlen; ++i)
-		{
-			tmpx = cdsj->x[i] - avex[i];
-			vari = tmpx * tmpx;
-			tmpy = cdsj->y[i] - avey[i];
-			vari += tmpy * tmpy;
-			tmpz = cdsj->z[i] - avez[i];
-			vari += tmpz * tmpz;
+        for (i = 0; i < vlen; ++i)
+        {
+            tmpx = cdsj->x[i] - avex[i];
+            vari = tmpx * tmpx;
+            tmpy = cdsj->y[i] - avey[i];
+            vari += tmpy * tmpy;
+            tmpz = cdsj->z[i] - avez[i];
+            vari += tmpz * tmpz;
 
             lagrange += vari / var[i];
-		}
+        }
     }
 
     lagrange = lagrange / (3.0 * cnum * vlen) - 1.0;
-    
+
     if (lagrange < 0.0)
         lagrange = 0.0;
-    
+
     printf("\nlagrange = % 12.6e", lagrange);
 
     for (i = 0; i < vlen; ++i)
@@ -740,7 +740,7 @@ CalcScaleFactorsML(CdsArray *cdsA)
         sigma2 /= (double) vlen;
 
         bsum = 1.0;
-    
+
         printf("\nsigma2 = %12.6e \n", sigma2);
 
         for (i = 0; i < cnum; ++i)
@@ -780,8 +780,8 @@ CalcScaleFactorsML(CdsArray *cdsA)
         double constraint = 0.0;
 
         for (i = 0; i < vlen; ++i)
-            constraint += wts[i] * (avecds->x[i] * avecds->x[i] + 
-                                    avecds->y[i] * avecds->y[i] + 
+            constraint += wts[i] * (avecds->x[i] * avecds->x[i] +
+                                    avecds->y[i] * avecds->y[i] +
                                     avecds->z[i] * avecds->z[i]);
 
         constraint = constraint / (3.0 * vlen) + 1.0;
@@ -873,7 +873,7 @@ NewtRaphScaleLogNorm(const double init, const double phi, const double gamma, co
        where the first derivative with repect to the lognormal scale
        estimate x (dF1/dx) is:
 
-          F1' = 
+          F1' =
     */
     beta = init;
     for (i = 0; i < 200; ++i)
@@ -1283,7 +1283,7 @@ static void
     int             i;
     double          deviation = 0.0;
     RotData        *rotdata = (RotData *) rotdata_ptr;
-    Cds         *cds;
+    Cds            *cds;
 
     for (i = rotdata->start; i < rotdata->end; ++i)
     {
@@ -1306,24 +1306,22 @@ static double
 CalcRotations_pth(CdsArray *cdsA, RotData **rotdata, pthread_t *callThd,
                   pthread_attr_t *attr, const int thrdnum)
 {
-    Cds        **cds = cdsA->cds;
-    const Cds   *avecds = cdsA->avecds;
+    Cds           **cds = cdsA->cds;
+    const Cds      *avecds = cdsA->avecds;
     const double   *wts = (const double *) cdsA->w;
-    Cds         *tcds = cdsA->tcds;
+    Cds            *tcds = cdsA->tcds;
     double          deviation_sum = 0.0;
     int             i, rc = 0, incr;
 
     if (cdsA->algo->covweight == 1)
     {
         MatMultCdsMultMatDiag(tcds,
-                                 (const double **) cdsA->WtMat,
-                                 avecds);
+                              (const double **) cdsA->WtMat,
+                              avecds);
     }
     else if (cdsA->algo->varweight == 1 || cdsA->algo->leastsquares == 1)
     {
-        MatDiagMultCdsMultMatDiag(tcds,
-                                     wts,
-                                     avecds);
+        MatDiagMultCdsMultMatDiag(tcds, wts, avecds);
     }
 
     incr = cdsA->cnum / thrdnum;
@@ -1405,10 +1403,10 @@ HierarchVars(CdsArray *cdsA)
             break;
 
         case 3:
-            InvGammaFitEvalsBfact(cdsA, 1); 
+            InvGammaFitEvalsBfact(cdsA, 1);
             break;
 
-        case 4: 
+        case 4:
             /* This is the old approximate method, used in versions 1.0-1.1  */
             /* inverse gamma fit of variances, excluding the smallest 3 */
             /* This accounts for the fact that the smallest three eigenvalues of the covariance
@@ -1423,7 +1421,7 @@ HierarchVars(CdsArray *cdsA)
         case 5: /* inverse gamma fit of variances, excluding the smallest 3 */
             /* This accounts for the fact that the smallest three eigenvalues of the covariance
                matrix are always zero, i.e. the covariance matrix is necessarily of rank
-               vlen - 3 (or usually less, with inadequate amounts of data 3N-6). 
+               vlen - 3 (or usually less, with inadequate amounts of data 3N-6).
                __Bayesian Bernardo reference prior on the scale and shape params__. */
             if (cdsA->algo->rounds > 4)
                 InvGammaBayesFitEvals(cdsA, 1);
@@ -1448,7 +1446,7 @@ HierarchVars(CdsArray *cdsA)
 //                 InvGammaFitEvalsEq(cdsA, 1);
 //             else
 //                 InvGammaFitEvalsEq(cdsA, 0);
-// 
+//
 //             if (cdsA->algo->verbose != 0)
 //                 printf("    HierarchVars() chi2:%f\n", cdsA->stats->hierarch_chi2);
 //             break;
@@ -1496,13 +1494,13 @@ HierarchVars(CdsArray *cdsA)
         case 12: /* inverse gamma fit of variances, excluding the smallest 3 */
             /* This accounts for the fact that the smallest three eigenvalues of the covariance
                matrix are always zero, i.e. the covariance matrix is necessarily of rank
-               vlen - 3 (or usually less, with inadequate amounts of data 3N-6). 
+               vlen - 3 (or usually less, with inadequate amounts of data 3N-6).
                No iterations */
             InvGammaFitEvals(cdsA, 0);
             break;
 
         case 13: /* Bayesian diagonal Wishart prior (proportional to the identity mat) on the
-                    variances/covmat, assuming improper reference prior on the precision 
+                    variances/covmat, assuming improper reference prior on the precision
                     hyperparameter */
             WishartFitVar(cdsA, 1);
             break;
@@ -1513,7 +1511,7 @@ HierarchVars(CdsArray *cdsA)
 //                 InvGammaBayesFitVars_fixed_c(cdsA, cdsA->algo->minc, 1);
 //             else
 //                 InvGammaBayesFitVars_fixed_c(cdsA, cdsA->algo->minc, 0);
-// 
+//
 //             if (cdsA->algo->verbose != 0)
 //                 printf("    HierarchVars() chi2:%f\n", cdsA->stats->hierarch_chi2);
             break;
@@ -1564,7 +1562,7 @@ HierarchVars(CdsArray *cdsA)
 
         case 21: /* ML fit of variances to a lognorml distribution */
             LognormalFitVars(cdsA, &zeta, &sigma);
-            LognormalAdjustVars(cdsA, zeta, sigma);             
+            LognormalAdjustVars(cdsA, zeta, sigma);
             break;
 
         case 22:
@@ -1808,7 +1806,7 @@ MultiPose(CdsArray *baseA)
     CdsArray    *scratchA = NULL; /* working scratch array, also holds average cds, */
                                      /* rotation matrices, translation and center vectors */
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     double          starttime, endtime;
     double          init, setup = 0.0, innerloop, exitloop;
 
@@ -1854,7 +1852,7 @@ MultiPose(CdsArray *baseA)
 
     //algo->constant = 0.001;
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     init = (double) (endtime - starttime) / 0.001;
     starttime = seconds();
@@ -1862,7 +1860,7 @@ MultiPose(CdsArray *baseA)
 
     /* Initialize the algorithm -- we need a centered mean structure as first guess */
     /* determine a structure to use as the initial mean structure */
-    if (algo->embedave != 0 || algo->alignment == 1)
+    if (algo->embedave != 0 /*|| algo->alignment == 1*/)
     {
         printf("    Calculating distance matrix for embedding average ... \n");
         fflush(NULL);
@@ -1925,17 +1923,17 @@ MultiPose(CdsArray *baseA)
 
     if (algo->scale > 0)
     {
-		//double fac, facsum = 0.0;
-		for (i = 0; i < cnum; ++i)
-		{
-			//fac = genrand_real2() * 100.0;
-			//facsum += fac;
-			//printf("\nfac[%3d]: % 12.6f", i+1, fac);
-			//ScaleCds(scratchA->cds[i], 1.0 / (i+1.0));
-			//ScaleCds(scratchA->cds[i], 1.0 / fac);
-			//scratchA->cds[i]->scale = 1.0 / (i+1.0);
-		}
-		//printf("\nfacsum: %12.6f", facsum);
+        //double fac, facsum = 0.0;
+        for (i = 0; i < cnum; ++i)
+        {
+            //fac = genrand_real2() * 100.0;
+            //facsum += fac;
+            //printf("\nfac[%3d]: % 12.6f", i+1, fac);
+            //ScaleCds(scratchA->cds[i], 1.0 / (i+1.0));
+            //ScaleCds(scratchA->cds[i], 1.0 / fac);
+            //scratchA->cds[i]->scale = 1.0 / (i+1.0);
+        }
+        //printf("\nfacsum: %12.6f", facsum);
     }
 
     /* The EM algorithm */
@@ -1943,7 +1941,7 @@ MultiPose(CdsArray *baseA)
        (1) First calculates the translations
        (2) Does inner loop -- calc rotations and average till convergence
        (3) Holding the superposition constant, calculates the covariance
-           matrices and corresponding weight matrices, looping till 
+           matrices and corresponding weight matrices, looping till
            convergence when using a dimensional/axial covariance matrix */
     round = 0;
     percent = lastpercent = 0.0;
@@ -2095,7 +2093,7 @@ MultiPose(CdsArray *baseA)
                 lastscale = cds[0]->scale;
 
                 double scaleprod;
-    
+
                 if (algo->scale == 1)
                     scaleprod = CalcScaleFactorsML(scratchA);
                 else if (algo->scale == 2)
@@ -2104,7 +2102,7 @@ MultiPose(CdsArray *baseA)
                     scaleprod = CalcScaleFactorsMLLogNorm(scratchA);
                 else
                     scaleprod = 1.0;
-    
+
                 printf("\n%5d scaleprod = %12.6f\n", round, scaleprod);
             }
 
@@ -2122,7 +2120,7 @@ MultiPose(CdsArray *baseA)
                 {
                     AveCds(scratchA);
 
-/* Calculate the ML estimate of a hierarchical mean, where the variance-weighted atoms 
+/* Calculate the ML estimate of a hierarchical mean, where the variance-weighted atoms
    are normally distributed with mean zero */
 /* See pdbUtils.c */
 /*                     double oldpsi = 0.0, psi = 0.0; */
@@ -2187,10 +2185,10 @@ MultiPose(CdsArray *baseA)
 
         /* Weighting by dimensional, axial Xi covariance matrix, here diagonal. */
         /* Holding the superposition constant, calculates the covariance
-           matrices and corresponding weight matrices, looping till 
+           matrices and corresponding weight matrices, looping till
            convergence. */
         CalcCovariances(scratchA);
-        
+
         //if (algo->scale > 0)
           //  ConstrainCovMat(scratchA);
 
@@ -2270,7 +2268,7 @@ MultiPose(CdsArray *baseA)
         GibbsMet(scratchA);
     }
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     innerloop = (double) (endtime - starttime) / 0.001;
     starttime = seconds();
@@ -2345,9 +2343,10 @@ MultiPose(CdsArray *baseA)
     { /* Write out a taxa distance matrix in NEXUS format */
         #include "DistMat.h"
 
-        DISTMAT *distmat;
+        DISTMAT *distmat = NULL;
         double sum;
         int j,k;
+        int cnt;
         char num[32];
         char *ptr = NULL;
         char *tree_name = NULL;
@@ -2364,21 +2363,82 @@ MultiPose(CdsArray *baseA)
             strcat(distmat->taxa[i], num);
         }
 
+//         for (i = 0; i < cnum; ++i)
+//         {
+//             for (j = 0; j <= i; ++j)
+//             {
+//                 sum = 0.0;
+//                 for (k = 0; k < vlen; ++k)
+//                     sum += SqrCdsDistMahal2((const Cds *) cds[i], k,
+//                                             (const Cds *) cds[j], k,
+//                                             (const double) scratchA->w[k]);
+//
+//                 distmat->dist[i][j] = sqrt(sum);
+//             }
+//         }
+
         for (i = 0; i < cnum; ++i)
         {
-            for (j = 0; j < cnum; ++j)
+            for (j = 0; j < i; ++j)
             {
                 sum = 0.0;
+                cnt = 0;
                 for (k = 0; k < vlen; ++k)
-                    sum += SqrCdsDistMahal2((const Cds *) cds[i], k,
-                                               (const Cds *) cds[j], k,
-                                               (const double) scratchA->w[k]);
+                {
+                    if (cds[i]->o[k] > 0 && cds[j]->o[k] > 0)
+                    {
+                        cnt += scratchA->w[k];
+                        sum += SqrCdsDistMahal2((const Cds *) cds[i], k,
+                                                (const Cds *) cds[j], k,
+                                                (const double) scratchA->w[k]);
+                    }
+                }
 
-                distmat->dist[i][j] = sqrt(sum);
+                distmat->dist[i][j] = sqrt(sum/(3.0*cnt));
             }
         }
 
-        tree_name = mystrcat(algo->rootname, "_tree.nxs");
+        tree_name = mystrcat(algo->rootname, "_ML_tree.nxs");
+        print_NX_distmat(distmat, tree_name);
+
+//         //double total = 0.0;
+//         for (i = 0; i < cnum; ++i)
+//         {
+//             for (j = 0; j < i; ++j)
+//             {
+//                 sum = 0.0;
+//                 for (k = 0; k < vlen; ++k)
+//                     sum += SqrCdsDist((const Cds *) cds[i], k,
+//                                       (const Cds *) cds[j], k);
+//
+//                 distmat->dist[i][j] = sqrt(sum/vlen);
+//                 //total += sum/vlen;
+//             }
+//         }
+
+        for (i = 0; i < cnum; ++i)
+        {
+            for (j = 0; j < i; ++j)
+            {
+                sum = 0.0;
+                cnt = 0;
+                for (k = 0; k < vlen; ++k)
+                {
+                    if (cds[i]->o[k] > 0 && cds[j]->o[k] > 0)
+                    {
+                        ++cnt;
+                        sum += SqrCdsDist((const Cds *) cds[i], k,
+                                          (const Cds *) cds[j], k);
+                    }
+                }
+
+                distmat->dist[i][j] = sqrt(sum/cnt);
+            }
+        }
+
+        //printf("\nrmsd? %g\n", sqrt(total/((cnum*cnum-  cnum)/2))); // verified same as paRMSD
+
+        tree_name = mystrcat(algo->rootname, "_LS_tree.nxs");
         print_NX_distmat(distmat, tree_name);
 
         if (tree_name != NULL)
@@ -2443,7 +2503,7 @@ MultiPose(CdsArray *baseA)
     /* wRMSD_from_mean does not need 2 in denominator, since it is already from the average */
     stats->wRMSD_from_mean = sqrt(deviation_sum / (double) (vlen * cnum));
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     exitloop = (double) (endtime - starttime) / 0.001;
     if (algo->verbose == 1)
@@ -2487,7 +2547,7 @@ MultiPose_pth(CdsArray *baseA)
     pthread_attr_t  attr;
 
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     double          starttime, endtime;
     double          init, setup = 0.0, innerloop, exitloop;
 
@@ -2537,13 +2597,13 @@ MultiPose_pth(CdsArray *baseA)
     stats->hierarch_p1 = 1.0;
     stats->hierarch_p2 = 1.0;
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     init = (double) (endtime - starttime) / 0.001;
     starttime = seconds();
 #endif
 
-    if (algo->embedave != 0 || algo->alignment == 1) // DLTIP
+    if (algo->embedave != 0 /*|| algo->alignment == 1*/) // DLTIP
     {
         printf("    Calculating distance matrix for embedding average ... \n");
         fflush(NULL);
@@ -2597,8 +2657,8 @@ MultiPose_pth(CdsArray *baseA)
        (1) First calculates the translations
        (2) Does inner loop -- calc rotations and average till convergence
        (3) Holding the superposition constant, calculates the covariance
-           matrices and corresponding weight matrices, looping till 
-           convergence when using a dimensional/axial covariance matrix 
+           matrices and corresponding weight matrices, looping till
+           convergence when using a dimensional/axial covariance matrix
     */
     percent = lastpercent = 0.0;
     round = 0;
@@ -2752,7 +2812,7 @@ MultiPose_pth(CdsArray *baseA)
 
         /* Weighting by dimensional, axial Xi covariance matrix, here diagonal. */
         /* Holding the superposition constant, calculates the covariance
-           matrices and corresponding weight matrices, looping till 
+           matrices and corresponding weight matrices, looping till
            convergence. */
         CalcCovariances(scratchA);
 
@@ -2766,7 +2826,7 @@ MultiPose_pth(CdsArray *baseA)
     if (algo->seed == 1)
         round -= 10;
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     innerloop = (double) (endtime - starttime) / 0.001;
     starttime = seconds();
@@ -2882,7 +2942,7 @@ MultiPose_pth(CdsArray *baseA)
     free(avedata);
     free(callThd);
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     endtime = seconds();
     exitloop = (double) (endtime - starttime) / 0.001;
     if (algo->verbose == 1)
@@ -3049,7 +3109,7 @@ SuperPose(Cds *cds1, Cds *cds2, double **rotmat, double *trans,
     if (sumdev > 1)
     {
         printf("  ERROR1111: -> sumdev: % 12.7e % 12.7e \n",
-                0.5 * sumdev / vlen, sqrt(fabs(0.5 * sumdev / vlen)) ); 
+                0.5 * sumdev / vlen, sqrt(fabs(0.5 * sumdev / vlen)) );
         printf("  ERROR1111: Please report to dtheobald@brandeis.edu \n");
 //        PrintTheseusTag();
 //        exit(EXIT_FAILURE);
