@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ range_selxn(int index, int *lower, int *upper, int range_num);
 static int
 atom_selxn(char *name, int mode);
 
-static const char atoms0[] = ":CA :C1*:";
+static const char atoms0[] = ":CA :C1*:C1'";
 static const char atoms1[] = ":N  :C  :O  :CA :";
 
 static int
@@ -185,7 +185,7 @@ Align2segID(PDBCdsArray *pdbA)
                     //fflush(NULL);
 
                     ++k;
-                    
+
                     if (k >= cdsi->vlen)
                         break;
                 }
@@ -195,7 +195,7 @@ Align2segID(PDBCdsArray *pdbA)
 }
 
 
-/* Dumps the sqrt of the variance in the B-factor column of the pdb file, based on corresponding 
+/* Dumps the sqrt of the variance in the B-factor column of the pdb file, based on corresponding
    residues in the sequence alignment.
    2010-10-12 */
 void
@@ -235,16 +235,16 @@ Align2Vars(PDBCdsArray *pdbA, CdsArray *cdsA)
                 else
                 {
                     resSeq = cdsi->resSeq[k];
-    
+
     /* printf("\n%s %4d %4d %4d %4d %s", cdsi->segID[k], i, k, resSeq, cdsi->resSeq[k], alnindex); */
     /* fflush(NULL); */
-    
+
                     while(cdsi->resSeq[k] == resSeq)
                     {
                         cdsi->tempFactor[k] = 0.0;
-    
+
                         ++k;
-                        
+
                         if (k >= cdsi->vlen)
                             break;
                     }
@@ -257,17 +257,17 @@ Align2Vars(PDBCdsArray *pdbA, CdsArray *cdsA)
                 if (seq[j] != '-') /* NOT a gap */
                 {
                     resSeq = cdsi->resSeq[k];
-    
+
     /* printf("\n%s %4d %4d %4d %4d %s", cdsi->segID[k], i, k, resSeq, cdsi->resSeq[k], alnindex); */
     /* fflush(NULL); */
                     if (m < cdsA->vlen)
-                    {    
+                    {
                         while(cdsi->resSeq[k] == resSeq)
                         {
                             cdsi->tempFactor[k] = sqrt(cdsA->var[m]);
-        
+
                             ++k;
-                            
+
                             if (k >= cdsi->vlen)
                                 break;
                         }
@@ -312,7 +312,7 @@ static Seq2PDB
     while(1)
     {
         ch = getc(mapfile);
-        
+
         if (ch == '#')
             while(ch != '\n')
                 ch = getc(mapfile);
@@ -374,7 +374,7 @@ GetSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
     char           *mapseqname_root = NULL;
     char           *mappdbname_root = NULL;
 
-    /* First set all flags in the MSA to 1, and later reset to 0 if the sequences have a 
+    /* First set all flags in the MSA to 1, and later reset to 0 if the sequences have a
        corresponding PDB file.
        This allows for sequences in the MSA that aren't being superpositioned. */
     for (i = 0; i < msa->seqnum; ++i)
@@ -417,7 +417,7 @@ GetSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
                         break;
                     }
                     fflush(NULL);
-                    
+
                     free(msaname_root);
                 }
 
@@ -454,7 +454,7 @@ GetSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
 }
 
 
-/* Same as above, but no mapfile needed as we assume that the sequence names and 
+/* Same as above, but no mapfile needed as we assume that the sequence names and
    PDB file names are identical */
 static void
 DefaultSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
@@ -463,7 +463,7 @@ DefaultSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
     const int       cnum = pdbA->cnum;
     char            filename_root[FILENAME_MAX], msaname_root[FILENAME_MAX];
 
-    /* First set all flags in the MSA to 1, and later reset to 0 if the sequences have a 
+    /* First set all flags in the MSA to 1, and later reset to 0 if the sequences have a
        corresponding PDB file.
        This allows for sequences in the MSA that aren't being superpositioned. */
     for (i = 0; i < msa->seqnum; ++i)
@@ -540,7 +540,7 @@ GetUbiqs(int *ubiqs, MSA *msa)
                 ++count;
         }
 //printf("\ncount[%d] = %d\n", i, count);
-        /* if ANY gaps were counted, set flag. 
+        /* if ANY gaps were counted, set flag.
            NOTE that this does not do anything for the other
            flags -- they are the same as when ubiqs was passed */
         if (count > 0)
@@ -693,7 +693,7 @@ ParseSelxns(PDBCdsArray *pdbA, char *selection, const int alignlen, int *singlet
             PrintTheseusTag();
             exit(EXIT_FAILURE);
         }
-        
+
         for (i = 0; i < pdbA->range_num; ++i)
         {
             selections[i] = (char *) calloc(128, sizeof(char));
@@ -703,11 +703,11 @@ ParseSelxns(PDBCdsArray *pdbA, char *selection, const int alignlen, int *singlet
                 fprintf(stderr, " ERROR: could not allocate memory for selections[] in GetCdsSelection(). \n\n");
                 PrintTheseusTag();
                 exit(EXIT_FAILURE);
-            }   
+            }
         }
 
         /* copy each range selection string into the 'selections[]' array */
-        mystrncpy(selections[0], strtok(selection, delims), 127); 
+        mystrncpy(selections[0], strtok(selection, delims), 127);
         for (i = 1; i < pdbA->range_num; ++i)
             mystrncpy(selections[i], strtok(NULL, delims), 127);
 
@@ -993,7 +993,9 @@ pdb2fst(PDBCdsArray *pdbA)
 
             if ( (strncmp(pdbA->cds[i]->record[j], "ATOM  ", 6) == 0 || strncmp(pdbA->cds[i]->record[j], "HETATM", 6) == 0)
                 &&
-                (strncmp(pdbA->cds[i]->name[j], "CA ", 3) == 0 || strncmp(pdbA->cds[i]->name[j], "C1*", 3) == 0) &&
+                (strncmp(pdbA->cds[i]->name[j], "CA ", 3) == 0 ||
+                 strncmp(pdbA->cds[i]->name[j], "C1*", 3) == 0 ||
+                 strncmp(pdbA->cds[i]->name[j], "C1'", 3) == 0) &&
                 (pdbA->cds[i]->altLoc[j] == ' ' || pdbA->cds[i]->altLoc[j] == 'A'))
             {
 				if (count % 72 == 0)
