@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@
 #include "pdbUtils.h"
 
 
-#if defined(__APPLE__)
+#if 0 // defined(__APPLE__)
     #include <CoreServices/CoreServices.h>
     #include <time.h>
     #include <sys/time.h>
@@ -69,7 +69,7 @@ CalcPCA(CdsArray *cdsA)
     char          *cov_name = NULL, *cor_name = NULL, *pcvecs_name = NULL, *pcstats_name = NULL;
 
 
-    #if defined(__APPLE__)
+    #if 0 //defined(__APPLE__)
         double               milliseconds;
         start_time = seconds();
     #endif
@@ -120,7 +120,7 @@ CalcPCA(CdsArray *cdsA)
 
     //MatPrint(cdsA->pcamat, vlen);
 
-    #if defined(__APPLE__)
+    #if 0 //defined(__APPLE__)
         end_time = seconds();
         milliseconds = (double) (end_time - start_time) / 0.001;
         printf("    PCs calculated in %.3f ms\n", milliseconds);
@@ -246,7 +246,7 @@ Calc3NPCA(CdsArray *cdsA)
     double                   biggest, bstick;
     char                     aster;
 
-    #if defined(__APPLE__)
+    #if 0 //defined(__APPLE__)
         double               milliseconds;
         start_time = seconds();
     #endif
@@ -290,7 +290,7 @@ Calc3NPCA(CdsArray *cdsA)
 
     PrintCovMatGnuPlot((const double **) evecs, vlen, "evecs.mat");
 
-    #if defined(__APPLE__)
+    #if 0 //defined(__APPLE__)
         end_time = seconds();
         milliseconds = (double) (end_time - start_time) / 0.001;
         printf("  PCs calculated in %.3f ms (Apple CoreServices)\n", milliseconds);
