@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -318,7 +318,6 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
     double        *p = calloc(protlen, sizeof(double));
     double       **randv = MatAlloc(protlen, 3), **randn = MatAlloc(protlen, 3);
     double        *diag = malloc(protlen * sizeof(double));
-    double        *invdiag = malloc(protlen * sizeof(double));
     Cds       **cds = cdsA->cds;
     Cds        *mcds = cdsA->cds[0];
     double         scale = 1.0;
@@ -331,8 +330,16 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
 //      for (i = 0; i < protlen; ++i)
 //          covmat[i][i] = 1.0;
 
+//      for (i = 0; i < protlen; ++i)
+//          covmat[i][i] = internmat[i][i];
+
+    memcpy(covmat[0], internmat[0], protlen * protlen * sizeof(double));
+
      for (i = 0; i < protlen; ++i)
-         covmat[i][i] = internmat[i][i];
+         diag[i] = covmat[i][i];
+         //diag[i] = invgamma_dev(cdsA->algo->param[0], cdsA->algo->param[1]);
+
+    CovMat2CorMat(covmat, protlen);
 
 /*     for (i = 0; i < protlen; ++i) */
 /*         printf("%-3d %f\n", i+1, covmat[i][i]); */
@@ -345,9 +352,6 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
     for (i = 0; i < protlen; ++i)
         printf("%-3d %f\n", i+1, diag[i]);
 
-    for (i = 0; i < protlen; ++i)
-        invdiag[i] = 1.0 / diag[i];
-
     CenMass(mcds);
     ApplyCenterIp(mcds);
 
@@ -380,12 +384,9 @@ RandCds(CdsArray *cdsA, const gsl_rng *r2)
             scale = RandScale(diag[j], cdsA->algo->random, 0, 0);
             /* printf("\n%d %f", j, scale); */
 
-            cds[i]->x[j] = mcds->x[j] +
-                              randv[j][0] * scale;
-            cds[i]->y[j] = mcds->y[j] +
-                              randv[j][1] * scale;
-            cds[i]->z[j] = mcds->z[j] +
-                              randv[j][2] * scale;
+            cds[i]->x[j] = mcds->x[j] + randv[j][0] * scale;
+            cds[i]->y[j] = mcds->y[j] + randv[j][1] * scale;
+            cds[i]->z[j] = mcds->z[j] + randv[j][2] * scale;
 /*             if (j == 0) */
 /*                 printf("\n%-3d % 8.3f % 8.3f % 8.3f", */
 /*                        i, cds[i]->x[j], cds[i]->y[j], cds[i]->z[j]); */
@@ -891,7 +892,7 @@ PDBCdsArray
         PDBCdsAlloc(pdbA->cds[i], minvlen);
     }
 
-    ReadPDBCds(pdbfile_name, pdbA, 0, 1, 0);
+    ReadPDBCds(pdbfile_name, pdbA, 0, 1, 0, 0);
 
     for (i = 1; i < cnum; ++i)
         PDBCdsCopyAll(pdbA->cds[i], (const PDBCds *) pdbA->cds[0]);
