@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 #include <sys/resource.h>
 #include <sys/types.h>
 #include <time.h>
+#include <gsl/gsl_math.h>
 #include <gsl/gsl_rng.h>
 #include <gsl/gsl_randist.h>
 #include <gsl/gsl_sort.h>
@@ -45,7 +46,7 @@
 #include "distfit_local.h"
 
 #define VERSION "0.90"
-#define DISTNUM 23
+#define DISTNUM 24
 
 /* array of function names */
 char
@@ -56,7 +57,7 @@ dist_name[DISTNUM][32] =
 	"Gamma",       "ChisqrGen",  "Lognormal",
 	"Invgamma",    "Invgauss",  "Recinvgauss", "Pareto",
 	"Exponential", "Invchisqr", "Chisqr",      "Chi",
-	"Rayleigh",
+	"Rayleigh", "Rice*",
 	"Maxwell",     "Beta",      "BetaSym", "BetaPrime"     //"Binomial"
 };
 
@@ -66,10 +67,10 @@ distfit_func[DISTNUM] =
 {
 	&normal_fit,    &laplace_fit,   &EVD_fit,         &logistic_fit,
 	&cauchy_fit,    &uniform_fit,   &weibull_fit, 
-	&gamma_fit,     &chisqrgen_fit,   &lognormal_fit,
+	&gamma_fit,     &chisqrgen_fit, &lognormal_fit,
 	&invgamma_fit,  &invgauss_fit,  &recinvgauss_fit, &pareto_fit,
 	&exp_fit,       &invchisqr_fit, &chisqr_fit,      &chi_fit,
-	&rayleigh_fit,
+	&rayleigh_fit,  &rice_fit,
 	&maxwell_fit,   &beta_fit,      &betasym_fit,  &betaprime_fit   //&binomial_fit
 };
 
@@ -82,7 +83,7 @@ distdev_func[DISTNUM] =
 	&gamma_dev,     &chisqrgen_dev, &lognormal_dev,
 	&invgamma_dev,  &invgauss_dev,  &recinvgauss_dev, &pareto_dev,
 	&exp_dev,       &invchisqr_dev, &chisqr_dev,      &chi_dev,
-	&rayleigh_dev,
+	&rayleigh_dev,  &rice_dev,
 	&maxwell_dev,   &beta_dev,      &betasym_dev,     &betaprime_dev //&binomial_dev
 };
 
@@ -91,10 +92,10 @@ distpdf_func[DISTNUM] =
 {
 	&normal_pdf,    &laplace_pdf,   &EVD_pdf,         &logistic_pdf,
 	&cauchy_pdf,    &uniform_pdf,   &weibull_pdf,
-	&gamma_pdf,     &chisqrgen_pdf,   &lognormal_pdf,
+	&gamma_pdf,     &chisqrgen_pdf, &lognormal_pdf,
 	&invgamma_pdf,  &invgauss_pdf,  &recinvgauss_pdf, &pareto_pdf,
 	&exp_pdf,       &invchisqr_pdf, &chisqr_pdf,      &chi_pdf,
-	&rayleigh_pdf,
+	&rayleigh_pdf,  &rice_pdf,
 	&maxwell_pdf,   &beta_pdf,      &betasym_pdf,     &betaprime_pdf //&binomial_pdf
 };
 
@@ -103,10 +104,10 @@ distcdf_func[DISTNUM] =
 {
 	&normal_cdf,    &laplace_cdf,   &EVD_cdf,         &logistic_cdf,
 	&cauchy_cdf,    &uniform_cdf,   &weibull_cdf,
-	&gamma_cdf,     &chisqrgen_cdf,   &lognormal_cdf,
+	&gamma_cdf,     &chisqrgen_cdf, &lognormal_cdf,
 	&invgamma_cdf,  &invgauss_cdf,  &recinvgauss_cdf, &pareto_cdf,
 	&exp_cdf,       &invchisqr_cdf, &chisqr_cdf,      &chi_cdf,
-	&rayleigh_cdf,
+	&rayleigh_cdf,  &rice_cdf,
 	&maxwell_cdf,   &beta_cdf,      &betasym_cdf,     &betaprime_cdf //&binomial_cdf
 };
 
@@ -115,10 +116,10 @@ distsdf_func[DISTNUM] =
 {
 	&normal_sdf,    &laplace_sdf,   &EVD_sdf,         &logistic_sdf,
 	&cauchy_sdf,    &uniform_sdf,   &weibull_sdf,
-	&gamma_sdf,     &chisqrgen_sdf,   &lognormal_sdf,
+	&gamma_sdf,     &chisqrgen_sdf, &lognormal_sdf,
 	&invgamma_sdf,  &invgauss_sdf,  &recinvgauss_sdf, &pareto_sdf,
 	&exp_sdf,       &invchisqr_sdf, &chisqr_sdf,      &chi_sdf,
-	&rayleigh_sdf,
+	&rayleigh_sdf,  &rice_sdf,
 	&maxwell_sdf,   &beta_sdf,      &betasym_sdf,     &betaprime_sdf //&binomial_sdf
 };
 
@@ -127,10 +128,10 @@ distint_func[DISTNUM] =
 {
 	&normal_int,    &laplace_int,   &EVD_int,         &logistic_int,
 	&cauchy_int,    &uniform_int,   &weibull_int,
-	&gamma_int,     &chisqrgen_int,   &lognormal_int,
+	&gamma_int,     &chisqrgen_int, &lognormal_int,
 	&invgamma_int,  &invgauss_int,  &recinvgauss_int, &pareto_int,
 	&exp_int,       &invchisqr_int, &chisqr_int,      &chi_int,
-	&rayleigh_int,
+	&rayleigh_int,  &rice_int,
 	&maxwell_int,   &beta_int,      &betasym_int,     &betaprime_int //&binomial_int
 };
 
@@ -142,7 +143,7 @@ dist_pnum[DISTNUM] =
 	2, 2, 2,
 	2, 2, 2, 2,
 	1, 1, 1, 1,
-	1,
+	1, 2,
 	1, 2, 1, 2 //2
 };
 
@@ -155,7 +156,7 @@ dist_nonneg[DISTNUM] =
 	1, 1, 0,
 	0, 0, 0, 0,
 	1, 0, 1, 1,
-	1,
+	1, 1,
 	1, 0, 0, 1 //1
 };
 
@@ -168,7 +169,7 @@ dist_posdef[DISTNUM] =
 	0, 0, 1,
 	1, 1, 1, 1,
 	0, 1, 0, 0,
-	0,
+	0, 0,
 	0, 0, 0, 0 //0
 };
 
@@ -180,7 +181,7 @@ dist_beta[DISTNUM] =
 	0, 0, 0,
 	0, 0, 0, 0,
 	0, 0, 0, 0,
-	0,
+	0, 0,
 	0, 1, 1, 0 //0
 };
 
@@ -194,6 +195,306 @@ double *sdfparams = NULL;
 double *intparams = NULL;
 
 
+/*
+Calculate the bias in the entropy estimate due to deviation from Normality.
+Based on on Edgeworth expansion of a PDF in terms of its cumulants (moments).
+
+See:
+
+Marc M. Van Hulle (2005)
+"Multivariate Edgeworth-based entropy estimation."
+2005 IEEE Workshop on Machine Learning for Signal Processing,
+Conference Proceedings
+28-28 Sept. 2005
+pp 311 - 316
+
+or
+
+Marc M. Van Hulle (2005)
+"Edgeworth Approximation of Multivariate Differential Entropy"
+Neural Computation 17, 1903–1910
+
+See equation 2.2.
+
+This bias term is substracted from the usual multivariate Gaussian
+entropy:
+
+0.5 * d * log(2.0 * M_PI * M_E) + 0.5 * lndet
+
+where lndet is the log of the determinant of the d*d covariance matrix.
+
+This could be combined more intelligently/efficiently with the
+covariance calculation.
+*/
+/*
+Comon, P. (1994)
+"Independent component analysis, a new concept?"
+Signal processing 36, 287–314.
+
+Amari, S.-I., Cichocki, A. and Yang, H. H. (1996)
+"A new learning algorithm for blind signal separation."
+Advances in neural information processing systems 8
+Eds. D. Touretzky, M. Mozer, and M. Hasselmo.
+MIT Press, Cambridge.
+757–763 (1996).
+*/
+double
+CalcEdgeworthVanHulleEntropy(double **vec, int dim, int len)
+{
+    int            i, j, k, m;
+    double        *ave = NULL;
+    double        *std = NULL;
+    double        *eval = NULL;
+    double       **dif = MatAlloc(dim,len);
+    double         term1, term2, term3;
+    double         term4, term5, term6;
+    double         t3, t4;
+    double         kappa_iii, kappa_iij, kappa_ijk;
+    double         kappa_iiii;
+    double         entropy, bias, lnscale, lndet, sum, var;
+    double       **cor = MatAlloc(dim,dim);
+    double       **cov = MatAlloc(dim,dim);
+    double         invlen = 1.0/len;
+
+
+    ave  = malloc(dim * sizeof(double));
+    std  = malloc(dim * sizeof(double));
+    eval = malloc(dim * sizeof(double));
+
+    /* First, normalize data vector to 0 mean, unit 1 variance */
+    for (i = 0; i < dim; ++i)
+        ave[i] = average(vec[i], len);
+
+    //VecPrint(ave, dim);
+
+    for (i = 0; i < dim; ++i)
+        for (j = 0; j < len; ++j)
+            dif[i][j] = vec[i][j] - ave[i];
+
+    for (i = 0; i < dim; ++i)
+    {
+        var = 0.0;
+        for (j = 0; j < len; ++j)
+            var += dif[i][j] * dif[i][j];
+        
+        std[i] = sqrt(var * invlen);
+    }
+
+    //VecPrint(std, dim);
+
+    /* Save the determinant of the scale transformation */
+    lnscale = 0.0;
+    for (i = 0; i < dim; ++i)
+        lnscale += log(std[i]);
+
+    /* rescale centered data */
+    for (i = 0; i < dim; ++i)
+        std[i] = 1.0 / std[i];
+
+    for (i = 0; i < dim; ++i)
+        for (j = 0; j < len; ++j)
+            dif[i][j] *= std[i];
+
+    /* Calculate the covariance matrix of transformed data (= correlation matrix) */
+    for (i = 0; i < dim; ++i)
+    {
+        for (j = 0; j <= i; ++j)
+        {
+            sum = 0.0;
+            for (k = 0; k < len; ++k)
+                sum += dif[i][k] * dif[j][k];
+
+            cor[i][j] = cor[j][i] = sum * invlen;
+        }
+    }
+
+//     printf ("\n\nEdgeworth correlation matrix:");
+//     MatPrintLowerDiag(cor, dim);
+// 
+//     for (i = 0; i < dim; ++i)
+//         for (j = 0; j < dim; ++j)
+//             cov[i][j] = cor[i][j] / (std[i] * std[j]);
+// 
+//     printf ("\n\nEdgeworth covariance matrix:");
+//     MatPrintLowerDiag(cov, dim);
+
+    EigenvalsGSL(cor, dim, eval);
+
+    //VecPrint(eval, dim);
+
+    lndet = 0.0;
+    for (i = 0; i < dim; i++)
+    {
+        if (isgreater(eval[i], DBL_EPSILON))
+        {
+            lndet += log(eval[i]);
+        }
+        else
+        {
+            printf("\n WARNING: excluding eigenvalue %d from determinant calculation", i);
+            printf("\n WARNING: eigenvalue[%d] = %g < %g", i, eval[i], FLT_EPSILON);
+        }
+    }
+
+    term1 = 0.0;
+    term4 = 0.0;
+    term5 = 0.0;
+    term6 = 0.0;
+    for (i = 0; i < dim; ++i)
+    {
+        kappa_iii = 0.0;
+        kappa_iiii = 0.0;
+        for (j = 0; j < len; ++j)
+        {
+            t3 = dif[i][j] * dif[i][j] * dif[i][j];
+            kappa_iii += t3; /* skewness */
+            kappa_iiii += t3 * dif[i][j]; /* kurtosis */
+        }
+
+        kappa_iii *= invlen;
+        kappa_iiii *= invlen;
+        kappa_iiii -= 3.0;
+
+        t3 = kappa_iii * kappa_iii;
+        t4 = kappa_iiii * kappa_iiii;
+        term1 += t3;
+        term4 += t4;
+        term5 += t3*t3;
+        term6 += t3 * kappa_iiii;
+    }
+
+    term2 = 0.0;
+    for (i = 0; i < dim; ++i)
+    {
+        for (j = 0; j < dim; ++j)
+        {
+            if (i != j)
+            {
+                kappa_iij = 0.0;
+                for (k = 0; k < len; ++k)
+                    kappa_iij += dif[i][k] * dif[i][k] * dif[j][k];
+
+                kappa_iij *= invlen;
+
+                term2 += kappa_iij * kappa_iij;
+            }
+        }
+    }
+
+    term3 = 0.0;
+    for (i = 0; i < dim; ++i)
+    {
+        for (j = 0; j < i; ++j)
+        {
+            for (k = 0; k < j; ++k)
+            {
+                kappa_ijk = 0.0;
+                for (m = 0; m < len; ++m)
+                    kappa_ijk += dif[i][m] * dif[j][m] * dif[k][m];
+
+                kappa_ijk *= invlen;
+
+                term3 += kappa_ijk * kappa_ijk;
+            }
+        }
+    }
+
+    /* There are d \kappa_{i,i,i} terms, 2 {d \choose 2} \kappa_{i,i,j} terms, 
+       and {d \choose 3} \kappa_{i,j,k} terms.
+       gsl_sf_choose (unsigned int n, unsigned int m) */
+
+    /* The following is based on Comon, P. (1994) Signal processing 36, 287–314.
+       See eqn 3.4 (Theorem 14).
+       The similar equations (7 & 8) in Amari, Cichocki, and Yang (1996) seem to be wrong.  */
+
+    bias = (term1 + 3.0 * term2 + term3 / 6.0) / 12.0 + term4/48.0 + 7.0*term5/48.0 - term6/8.0;
+
+    printf("\nEdgeworth term1: %g", term1/ 12.0);
+    printf("\nEdgeworth term2: %g", 3.0*term2/ 12.0);
+    printf("\nEdgeworth term3: %g", term3/(6.0*12.0));
+    printf("\nEdgeworth term4: %g", +term4/48.0);
+    printf("\nEdgeworth term5: %g", +7.0*term5/48.0);
+    printf("\nEdgeworth term6: %g\n", - term6/8.0);
+
+    printf("\nln(det):           %14.3f", lndet);
+
+    entropy = 0.5 * dim * log(2.0 * M_PI * M_E) + 0.5 * lndet;
+    
+    printf("\nwhite entropy:     %14.3f", entropy);
+    printf("\nbias:              %14.3f", bias);
+    printf("\nln(scale):         %14.3f", lnscale);
+
+    printf("\nNaive N-entropy:   %14.3f", entropy + lnscale);
+
+    //entropy = entropy - bias + lnscale;
+    
+    printf("\nEdgeworth entropy: %14.3f", entropy - term1/12.0 + lnscale);
+    printf("\nEdgeworth entropy (4th order corrections): %14.3f", entropy - bias + lnscale);
+    printf("\n\n");
+
+//     term1 = 0.0;
+//     term4 = 0.0;
+//     term5 = 0.0;
+//     term6 = 0.0;
+//     for (i = 0; i < dim; ++i)
+//     {
+//         kappa_iii = 0.0;
+//         kappa_iiii = 0.0;
+//         for (j = 0; j < len; ++j)
+//         {
+//             t3 = dif[i][j] * dif[i][j] * dif[i][j];
+//             kappa_iii += t3; /* skewness */
+//             kappa_iiii += t3 * dif[i][j]; /* kurtosis */
+//         }
+// 
+//         kappa_iii *= invlen;
+//         kappa_iiii *= invlen;
+//         kappa_iiii -= 3.0;
+// 
+//         t3 = kappa_iii * kappa_iii;
+//         t4 = kappa_iiii * kappa_iiii;
+//         term1 += t3;
+//         term4 += t4;
+//         term5 += t4 * kappa_iiii; // k_4^3;
+//         term6 += t3 * kappa_iiii; // k_3^2 k_4
+//     }
+// 
+//     bias = (term1 + 3.0 * term2 + term3 / 6.0) / 12.0 + term4/48.0 - term5/16.0 - 5.0*term6/8.0;
+// 
+//     printf("\nEdgeworth term1: %g", term1/ 12.0);
+//     printf("\nEdgeworth term2: %g", 3.0*term2/ 12.0);
+//     printf("\nEdgeworth term3: %g", term3/(6.0*12.0));
+//     printf("\nEdgeworth term4: %g", +term4/48.0);
+//     printf("\nEdgeworth term5: %g", -term5/16.0);
+//     printf("\nEdgeworth term6: %g\n", - 5.0*term6/8.0);
+// 
+//     printf("\nln(det):           %14.3f", lndet);
+// 
+//     entropy = 0.5 * dim * log(2.0 * M_PI * M_E) + 0.5 * lndet;
+//     
+//     printf("\nwhite entropy:     %14.3f", entropy);
+//     printf("\nbias:              %14.3f", bias);
+//     printf("\nln(scale):         %14.3f", lnscale);
+// 
+//     printf("\nNaive N-entropy:   %14.3f", entropy + lnscale);
+// 
+//     //entropy = entropy - bias + lnscale;
+//     
+//     printf("\nEdgeworth entropy: %14.3f", entropy - term1/12.0 + lnscale);
+//     printf("\nEdgeworth entropy: %14.3f", entropy - bias + lnscale);
+//     printf("\n\n");
+
+    MatDestroy(&dif);
+    MatDestroy(&cor);
+    MatDestroy(&cov);
+    free(eval);
+    free(std);
+    free(ave);
+
+    return(entropy);
+}
+
+
 double
 FindMode(const double *x, const int len)
 {
@@ -648,6 +949,9 @@ main(int argc, char *argv[])
 
     moments(array, length, &ave, &median, &adev, &mdev, &sdev, &var, &skew, &kurt, &hrange, &lrange);
 
+    double **arrayp = &array;
+    CalcEdgeworthVanHulleEntropy(arrayp, 1, length);
+
     printf("\n\nData      average      median     ave dev     med dev     std dev    variance    skewness    kurtosis\n");
     printf(  "----  ----------- ----------- ----------- ----------- ----------- ----------- ----------- -----------\n");
     printf("%-5d % 11.3e % 11.3e % 11.3e % 11.3e % 11.3e % 11.3e % 11.3e % 11.3e\n",
@@ -1255,7 +1559,7 @@ PrintDistStats(DistStats **diststats, int distnum)
         fflush(NULL);
     }
 
-    printf("\n");
+    printf("\n * broken \n\n");
     fflush(NULL);
 }
 
@@ -1359,8 +1663,8 @@ Usage(void)
     fprintf(stderr, "     (4)  Cauchy,       (5)  Uniform,   (6)  Weibull,  (7)  Gamma, \n");
     fprintf(stderr, "     (8)  ChiSqrGen,    (9)  Lognormal, (10) InvGamma, (11) InvGauss, \n");
     fprintf(stderr, "     (12) RecInvGauss,  (13) Pareto,    (14) Exp,      (15) InvChiSqr, \n");
-    fprintf(stderr, "     (16) ChiSqr,       (17) Chi,       (18) Rayleigh  (19) Maxwell,  \n"); 
-    fprintf(stderr, "     (20) Beta,         (21) BetaSymm,  (22) BetaPrime \n");
+    fprintf(stderr, "     (16) ChiSqr,       (17) Chi,       (18) Rayleigh  (19) Rice, \n"); 
+    fprintf(stderr, "     (20) Maxwell,      (21) Beta,      (22) BetaSymm, (23) BetaPrime \n");
     fprintf(stderr, "  -D {distribution} -- distribution to simulate, use w/ -np \n");
     fprintf(stderr, "  -m {# of mixtures} -- fit a normal mixture distribution \n");
     fprintf(stderr, "  -n {# replicates} -- number of variates to simulate \n");
@@ -1374,7 +1678,8 @@ Usage(void)
     fprintf(stderr, "  -t -- do a series of simple data transformations and refit \n");
     fprintf(stderr, "  -z -- \"fix\" zeros by setting to DBL_EPSILON (%e) \n", DBL_EPSILON);
     fprintf(stderr, "  -o -- \"fix\" ones by setting to 1.0 - DBL_EPSILON \n");
-    fprintf(stderr, "  -v -- version \n\n");
+    fprintf(stderr, "  -v -- version \n");
+    fprintf(stderr, "  * broken \n\n");
     fflush(NULL);
 }
 
