@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -749,7 +749,7 @@ sech(const double d);
 #ifndef LOGNORMAL_SEEN
 #define LOGNORMAL_SEEN
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__GLIBC__)
     extern double erf(double x);
 #endif
 
@@ -1516,7 +1516,7 @@ uniform_fit(const double *x, const int n, double *alpha, double *beta, double *p
 #ifndef VONMISES_DIST_SEEN
 #define VONMISES_DIST_SEEN
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__GLIBC__)
     extern double jn(int n, double x);
 #endif
 
@@ -1596,3 +1596,44 @@ eval_hist_weibullML(const double *x, double *freq, const int nx,
                     double *params, double *fvec, double **fjac);
 
 #endif
+
+#ifndef RICE_DIST_SEEN
+#define RICE_DIST_SEEN
+
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
+
+double
+rice_dev(const double mu, const double var, const gsl_rng *r2);
+
+double
+rice_pdf(const double x, const double mean, const double var);
+
+double
+rice_lnpdf(const double x, const double mean, const double var);
+
+double
+rice_cdf(const double x, const double mean, const double var);
+
+double
+rice_sdf(const double x, const double mean, const double var);
+
+double
+rice_int(const double x, const double y, const double mean, const double var);
+
+double
+rice_logL(const double mean, const double var);
+
+double
+rice_fit(const double *x, const int n, double *mean, double *var, double *prob);
+
+double
+rice_fit_w(const double *x, const int n, const double *wts, double *mean,
+             double *var, double *logL);
+
+void
+rice_init_mix_params(const double *x, const int n, const int mixn,
+                       double *mean, double *var);
+
+#endif
+
