@@ -35,7 +35,7 @@
 #include "DLTutils.h"
 
 /* #undef __APPLE__ */
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     #if !defined(inline) 
         #define inline __inline__ 
     #endif 
