@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2012 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -168,9 +168,6 @@ MatTransOp(double **outmat, const double **inmat, const int dim);
 void 
 cholesky(double **mat, const int dim, double *p);
 
-void
-MatInvLAPACK(double **inmat, double **outmat, int vlen);
-
 double
 MatDet(const double **mat, const int dim);
 
@@ -752,7 +749,7 @@ sech(const double d);
 #ifndef LOGNORMAL_SEEN
 #define LOGNORMAL_SEEN
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__GLIBC__)
     extern double erf(double x);
 #endif
 
@@ -1454,6 +1451,40 @@ double
 stdnormal(void);
 
 #endif
+
+#ifndef RAYLEIGH_DIST_SEEN
+#define RAYLEIGH_DIST_SEEN
+
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
+
+double
+rayleigh_dev(const double a, const double b, const gsl_rng *r2);
+
+double
+rayleigh_pdf(const double x, const double a, const double b);
+
+double
+rayleigh_lnpdf(const double x, const double a, const double b);
+
+double
+rayleigh_cdf(const double x, const double a, const double b);
+
+double
+rayleigh_sdf(const double x, const double a, const double b);
+
+double
+rayleigh_int(const double x, const double y, const double a, const double b);
+
+double
+rayleigh_logL(const double a, const double b);
+
+double
+rayleigh_fit(const double *x, const int n, double *eta, double *beta, double *prob);
+
+#endif
+
+
 #ifndef UNIFORM_DIST_SEEN
 #define UNIFORM_DIST_SEEN
 
@@ -1485,7 +1516,7 @@ uniform_fit(const double *x, const int n, double *alpha, double *beta, double *p
 #ifndef VONMISES_DIST_SEEN
 #define VONMISES_DIST_SEEN
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__GLIBC__)
     extern double jn(int n, double x);
 #endif
 
@@ -1565,3 +1596,44 @@ eval_hist_weibullML(const double *x, double *freq, const int nx,
                     double *params, double *fvec, double **fjac);
 
 #endif
+
+#ifndef RICE_DIST_SEEN
+#define RICE_DIST_SEEN
+
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
+
+double
+rice_dev(const double mu, const double var, const gsl_rng *r2);
+
+double
+rice_pdf(const double x, const double mean, const double var);
+
+double
+rice_lnpdf(const double x, const double mean, const double var);
+
+double
+rice_cdf(const double x, const double mean, const double var);
+
+double
+rice_sdf(const double x, const double mean, const double var);
+
+double
+rice_int(const double x, const double y, const double mean, const double var);
+
+double
+rice_logL(const double mean, const double var);
+
+double
+rice_fit(const double *x, const int n, double *mean, double *var, double *prob);
+
+double
+rice_fit_w(const double *x, const int n, const double *wts, double *mean,
+             double *var, double *logL);
+
+void
+rice_init_mix_params(const double *x, const int n, const int mixn,
+                       double *mean, double *var);
+
+#endif
+
