@@ -418,7 +418,7 @@ evalgammaEM(const double logterm, const double b, const double c, double *fx, do
 double
 gamma_fit(const double *data, const int num, double *b, double *c, double *logL)
 {
-    double          ave, /* var,  */logterm, logdata, fx, dfx, fxdfx, guess_b, guess_c;
+    double          ave, /* var,  */logterm, logdata, fx, dfx, fxdfx;
     int             i, maxiter = 500;
     double          tol = FLT_EPSILON;
 
@@ -465,9 +465,6 @@ gamma_fit(const double *data, const int num, double *b, double *c, double *logL)
     if (*c > FLT_MAX)
         *c = FLT_MAX;
 
-    guess_b = *b;
-    guess_c = *c;
-
     /* Maximum likelihood fit. */
     /* Use Newton-Raphson to find ML estimate of c
        Based on _Statistical Distributions_ 3rd ed. Evans, Hastings, and Peacock, p 41.
@@ -701,7 +698,7 @@ gamma_fit_no_stats(const double *data, const int num, double *b, double *c)
 void
 gamma_bayes_fit_no_stats(const double *data, const int num, double *b, double *c)
 {
-    double          ave, /* var,  */logterm, logdata, fx, dfx, fxdfx, guess_b, guess_c;
+    double          ave, /* var,  */logterm, logdata, fx, dfx, fxdfx;
     int             i, maxiter = 500;
     double          tol = FLT_EPSILON;
 
@@ -758,8 +755,6 @@ gamma_bayes_fit_no_stats(const double *data, const int num, double *b, double *c
     if (*c > FLT_MAX)
         *c = FLT_MAX;
 
-    guess_b = *b;
-    guess_c = *c;
     /* Bayesian maximum posterior probability fit.
        Use Newton-Raphson to find ML estimate of c.
 
@@ -837,7 +832,7 @@ gamma_bayes_fit_no_stats(const double *data, const int num, double *b, double *c
 void
 gamma_bayes_ref_fit_no_stats(const double *data, const int num, double *b, double *c)
 {
-    double          sumx, /* var,  */logterm, logdata, fx, dfx, fxdfx, guess_b, guess_c;
+    double          sumx, /* var,  */logterm, logdata, fx, dfx, fxdfx;
     int             i, maxiter = 500;
     double          tol = FLT_EPSILON;
 
@@ -892,8 +887,6 @@ gamma_bayes_ref_fit_no_stats(const double *data, const int num, double *b, doubl
     if (*c > FLT_MAX)
         *c = FLT_MAX;
 
-    guess_b = *b;
-    guess_c = *c;
     /* Bayesian maximum posterior probability fit.
        Use Newton-Raphson to find ML estimate of c.
 
