@@ -764,7 +764,7 @@ evalinvgammaML2(const int num, const double sum_ln, const double b, const double
 double
 invgamma_EMsmall_fit(const double *data, const int numt, int missing, double *b, double *c, double *logL)
 {
-    double          sum_ln, sum_inv, ave_ln, ave_inv, harm_ave, x;
+    double          sum_ln, sum_inv, ave_ln, harm_ave, x;
     double         *newdata = malloc(numt * sizeof(double));
     double          chi2 = 0.0, xn1, expinvxn, explogxn;
     double          fx = 0.0, dfx = 1.0, fxdfx = 0.0;
@@ -798,7 +798,7 @@ invgamma_EMsmall_fit(const double *data, const int numt, int missing, double *b,
     numm = numt - missing;
 
     ave_ln = sum_ln / numm;
-    ave_inv = sum_inv / numm;
+    // ave_inv = sum_inv / numm;
     harm_ave = numm / sum_inv;
 
     /* MMEs are:
