@@ -29,7 +29,6 @@
 #include <stdlib.h>
 #include <float.h>
 #include "DLTmath.h"
-#include "lapack_dlt.h"
 #include "eigen.h"
 #include "MatUtils.h"
 #include "Mat3Utils.h"
@@ -542,47 +541,6 @@ VerifyRotMat(double **rotmat, double tol)
 }
 
 
-/* returns the closest orthogonal, normalized, rotation matrix to the 
-   input matrix */
-double
-**ClosestRotMat(double **inmat)
-{
-    double        **rotmat = MatAlloc(3, 3);
-    double        **u = MatAlloc(3, 3);
-    double        **vt = MatAlloc(3, 3);
-    double         *s = malloc(3 * sizeof(double));
-    int             i, j, k;
-
-    dgesvd_opt_dest(inmat, 3, 3, u, s, vt);
-
-    /* this guarantees that the determinant of the rot mat is positive,
-       as required */
-
-    s[0] = s[1] = 1.0;
-    s[2] = Mat3Det((const double **)u) * Mat3Det((const double **)vt);
-
-    /* Mat3MultUSVOp(rotmat, (const double **) u, s, (const double **) vt); */
-
-    for (i = 0; i < 3; ++i)
-    {
-        for (j = 0; j < 3; ++j)
-        {
-            rotmat[i][j] = 0.0;
-            for (k = 0; k < 3; ++k)
-                rotmat[i][j] += (u[k][i] * s[k] * vt[j][k]);
-        } /* NB: LAPACK uses Fortran-style transposed matrices */
-    }
-
-    printf(" det = %e\n", Mat3Det((const double **)rotmat));
-
-    MatDestroy(&u);
-    MatDestroy(&vt);
-    free(s);
-
-    return(rotmat);
-}
-
-
 /* returns the closest orthogonal, normalized, rotation matrix to the 
    input matrix */
 void
@@ -593,7 +551,11 @@ ClosestRotMatIp(double **inmat)
     double         *s = malloc(3 * sizeof(double));
     Mat3Print(inmat);
 
-    dgesvd_opt_dest(inmat, 3, 3, u, s, vt);
+    svdGSLDest(inmat, 3, s, vt);
+    Mat3TransposeIp(vt);
+    Mat3Cpy(u, (const double **) inmat);
+
+    //dgesvd_opt_dest(inmat, 3, 3, u, s, vt);
 
     /* this guarantees that the determinant of the rot mat is positive,
        as required */
