@@ -1290,12 +1290,6 @@ rotate(double **a, double s, double theta,
 }
 
 
-#if defined(__APPLE__)
-    #include <vecLib/clapack.h>
-    #include <vecLib/cblas.h>
-#endif
-
-
 /* Calculates the Moore-Penrose pseudoinverse of a symmetric matrix
    (if necessary). Returns the condition number of the matrix.
    */
