@@ -2631,6 +2631,88 @@ writealn(MSA *msa, int begin, int window, char *outfile_root)
 }
 
 
+
+void
+writephylip(MSA *msa, int begin, int window, char *outfile_root)
+{
+    FILE          *outfile = NULL;
+    int            i, j, k, blocks;
+    char          *outfile_name = NULL;
+
+    outfile_name = (char *) malloc(256 * sizeof(char)); 
+    if (outfile_name == NULL)
+    {
+        perror("\n ERROR");
+        fprintf(stderr, "\n ERROR24: Could not allocate memory for outfile_name in function writealn(). \n\n");
+        exit(EXIT_FAILURE);
+    }
+
+    mystrncpy(outfile_name, outfile_root, FILENAME_MAX);
+    strcat(outfile_name, ".phy");
+    outfile = fopen(outfile_name, "w");
+    if (outfile == NULL)
+    {
+        perror("\n ERROR");
+        fprintf(stderr, "\n ERROR25: file \"%s\" not found. \n\n", outfile_name);
+        exit(EXIT_FAILURE);
+    }
+
+    fprintf(outfile, "%d %d\n", msa->seqnum, msa->seqlen);
+
+    if (window > (msa->seqlen - begin))
+        window = (msa->seqlen - begin);
+
+    for (i = 0; i < msa->seqnum; ++i)
+    {
+        msa->flag2[i] = 0;
+
+        j = begin; 
+        while((msa->seq[i][j] == '-' ||
+               msa->seq[i][j] == '?' ||
+               msa->seq[i][j] == '.') &&
+              j < begin + window)
+            ++j;
+
+//printf("flag2[i]:%d\n", msa->flag2[i] );
+
+        if (j >= begin + window)
+            msa->flag2[i] = 1;
+    }
+
+    blocks = (int) (window / MAXLINE + 1);
+    //printf("blocks:%d\n", blocks);
+
+    for(i = 0; i < blocks; ++i)
+    {
+        for(j = 0; j < msa->seqnum; ++j) /* for every sequence */
+        {
+            //printf("flag2[j]:%d flag[j]:%d\n", msa->flag2[j], msa->flag[j] );
+            if ((msa->flag2[j] == 1) || (msa->flag[j] == 1))
+                continue;
+
+            /* fprintf(outfile, "%-30.30s      ", msa->name[j]); */
+            if (i == 0)
+                fprintf(outfile, "%-20.20s ", msa->name[j]);
+
+            for (k = begin + i*MAXLINE;
+                 k < begin + window &&
+                 k < msa->seqlen &&
+                 k < (begin + i*MAXLINE + MAXLINE);  
+                 ++k)
+            {
+                fputc(msa->seq[j][k], outfile);
+            }
+            fputc('\n', outfile);
+        }
+        fputc('\n', outfile);
+    }
+
+    fputc('\n', outfile);
+    fclose(outfile);
+    free(outfile_name);
+}
+
+
 void
 writenex(MSA *msa, int begin, int window, char *outfile_root)
 {
