@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,9 +41,9 @@
 #include "DLTmath.h"
 
 
-static const char atoms0[] = "CA :C1*";
-static const char atoms1[] = "N  :C  :O  :CA :P  :C1*:O3*:O5*:C3*:C4*:C5*:";
-static const char atoms3[] = "CA :CB :P  :C1*";
+static const char atoms0[] = "CA :C1*:C1'";
+static const char atoms1[] = "N  :C  :O  :CA :P  :C1*:C1':O3*:O3':O5*:O5':C3*:C3':C4*:C4':C5*:C5'";
+static const char atoms3[] = "CA :CB :P  :C1*:C1'";
 
 
 static int
@@ -179,25 +179,49 @@ XPLORcorrections(PDBCds *pdbcds, int record)
         memcpy(pdbcds->resName[record], "  U", 3);
 }
 
+/* http://www.wwpdb.org/documentation/format33/sect9.html */
+
+/*
+Coordinate Section, ATOM, Version 3.3: July, 2011
+
+COLUMNS        DATA  TYPE    FIELD        DEFINITION
+-------------------------------------------------------------------------------------
+ 1 -  6        Record name   "ATOM  "
+ 7 - 11        Integer       serial       Atom  serial number.
+13 - 16        Atom          name         Atom name.
+17             Character     altLoc       Alternate location indicator.
+18 - 20        Residue name  resName      Residue name.
+22             Character     chainID      Chain identifier.
+23 - 26        Integer       resSeq       Residue sequence number.
+27             AChar         iCode        Code for insertion of residues.
+31 - 38        Real(8.3)     x            Orthogonal coordinates for X in Angstroms.
+39 - 46        Real(8.3)     y            Orthogonal coordinates for Y in Angstroms.
+47 - 54        Real(8.3)     z            Orthogonal coordinates for Z in Angstroms.
+55 - 60        Real(6.2)     occupancy    Occupancy.
+61 - 66        Real(6.2)     tempFactor   Temperature  factor.
+77 - 78        LString(2)    element      Element symbol, right-justified.
+79 - 80        LString(2)    charge       Charge  on the atom.
+*/
 
 static void
-ScanPDBLine(char *buff, PDBCds *cp, int j)
+ScanPDBLine(char *buff, PDBCds *cp, int j, int amber)
 {
     char           *endline = NULL;
-    char            amber_atom_name = buff[12];
+    //char            amber_atom_name = buff[12];
 
     endline = strpbrk(&buff[54], "\r\n\f");
     if (endline != NULL) /* kill the newline, if there */
         *endline = '\0';
 
-    if (!isdigit(amber_atom_name) && !isspace(amber_atom_name)) /* for nonstandard PDB files, with atom name in wrong column (shifted one to the left, such as with AMBER8) */
+    //if (!isdigit(amber_atom_name) && !isspace(amber_atom_name))
+    if (amber)  /* for nonstandard PDB files, with atom name in wrong column (shifted one to the left, such as with AMBER8, hosers) */
     {
-        /*         1         2         3         4         5         6         7         8
+        /*       1         2         3         4         5         6         7         8
         12345678901234567890123456789012345678901234567890123456789012345678901234567890
         ATOM    145  N   VAL A  25      32.433  16.336  57.540  1.00 11.92      A1   N
-        ATOM    146  CA  VAL A  25      31.132  16.439  58.160  1.00 11.85      A1   C  
-        ATOM  15088 1HG1 ILE    28      -3.430   4.303  -6.057  1.00  0.00           H  
-        ATOM   7580 HD23 LEU  1724     111.285  90.889 -61.535                      
+        ATOM    146  CA  VAL A  25      31.132  16.439  58.160  1.00 11.85      A1   C
+        ATOM  15088 1HG1 ILE    28      -3.430   4.303  -6.057  1.00  0.00           H
+        ATOM   7580 HD23 LEU  1724     111.285  90.889 -61.535
         */
                                                       /* #  COLs  LEN  DATA TYPE    FIELD      DEFINITION */
         sscanf(&buff[0],  "%6c",   cp->record[j]);    /* 1  0-5   6    Record name  "ATOM  " */
@@ -211,8 +235,8 @@ ScanPDBLine(char *buff, PDBCds *cp, int j)
         sscanf(&buff[22], "%4d",  &cp->resSeq[j]);    /* 9  22-25 4    Integer      resSeq     Residue sequence number. */
         sscanf(&buff[26], "%1c",  &cp->iCode[j]);     /* 10 26    1    AChar        iCode      Code for insertion of residues. */
         sscanf(&buff[30], "%8lf", &cp->x[j]);         /* 11 30-37 8    Real(8.3)    x          Orthogonal coordinates for X */
-        sscanf(&buff[38], "%8lf", &cp->y[j]);         /* 12 30-37 8    Real(8.3)    y          Orthogonal coordinates for Y */
-        sscanf(&buff[46], "%8lf", &cp->z[j]);         /* 13 30-37 8    Real(8.3)    z          Orthogonal coordinates for Z */
+        sscanf(&buff[38], "%8lf", &cp->y[j]);         /* 12 38-45 8    Real(8.3)    y          Orthogonal coordinates for Y */
+        sscanf(&buff[46], "%8lf", &cp->z[j]);         /* 13 46-53 8    Real(8.3)    z          Orthogonal coordinates for Z */
         sscanf(&buff[54], "%6lf", &cp->occupancy[j]); /* 14 54-59 6    Real(6.2)    occupancy  Occupancy. */
         sscanf(&buff[60], "%6lf", &cp->tempFactor[j]);/* 15 60-65 6    Real(6.2)    tempFactor Temperature factor. */
         sscanf(&buff[72], "%4c",   cp->segID[j]);     /* 16 72-75 4    LString(4)   segID      Segment identifier, left-just. */
@@ -221,12 +245,12 @@ ScanPDBLine(char *buff, PDBCds *cp, int j)
     }
     else /* standard PDB format http://www.rcsb.org/pdb/file_formats/pdb/pdbguide2.2/guide2.2_frame.html */
     {
-        /*          1         2         3         4         5         6         7         8
+        /*        1         2         3         4         5         6         7         8
         012345678901234567890123456789012345678901234567890123456789012345678901234567890
         ATOM    145  N   VAL A  25      32.433  16.336  57.540  1.00 11.92      A1   N
-        ATOM    146  CA  VAL A  25      31.132  16.439  58.160  1.00 11.85      A1   C  
-        ATOM  15088 1HG1 ILE    28      -3.430   4.303  -6.057  1.00  0.00           H  
-        ATOM   7580 HD23 LEU  1724     111.285  90.889 -61.535                      
+        ATOM    146  CA  VAL A  25      31.132  16.439  58.160  1.00 11.85      A1   C
+        ATOM  15088 1HG1 ILE    28      -3.430   4.303  -6.057  1.00  0.00           H
+        ATOM   7580 HD23 LEU  1724     111.285  90.889 -61.535
         */
                                                       /* #  COLs  LEN  DATA TYPE    FIELD      DEFINITION */
         sscanf(&buff[0],  "%6c",   cp->record[j]);    /* 1  0-5   6    Record name  "ATOM  " */
@@ -240,14 +264,14 @@ ScanPDBLine(char *buff, PDBCds *cp, int j)
         sscanf(&buff[22], "%4d",  &cp->resSeq[j]);    /* 9  22-25 4    Integer      resSeq     Residue sequence number. */
         sscanf(&buff[26], "%1c",  &cp->iCode[j]);     /* 10 26    1    AChar        iCode      Code for insertion of residues. */
         sscanf(&buff[30], "%8lf", &cp->x[j]);         /* 11 30-37 8    Real(8.3)    x          Orthogonal coordinates for X */
-        sscanf(&buff[38], "%8lf", &cp->y[j]);         /* 12 30-37 8    Real(8.3)    y          Orthogonal coordinates for Y */
-        sscanf(&buff[46], "%8lf", &cp->z[j]);         /* 13 30-37 8    Real(8.3)    z          Orthogonal coordinates for Z */
+        sscanf(&buff[38], "%8lf", &cp->y[j]);         /* 12 38-45 8    Real(8.3)    y          Orthogonal coordinates for Y */
+        sscanf(&buff[46], "%8lf", &cp->z[j]);         /* 13 46-53 8    Real(8.3)    z          Orthogonal coordinates for Z */
         sscanf(&buff[54], "%6lf", &cp->occupancy[j]); /* 14 54-59 6    Real(6.2)    occupancy  Occupancy. */
         sscanf(&buff[60], "%6lf", &cp->tempFactor[j]);/* 15 60-65 6    Real(6.2)    tempFactor Temperature factor. */
         sscanf(&buff[72], "%4c",   cp->segID[j]);     /* 16 72-75 4    LString(4)   segID      Segment identifier, left-just. */
         sscanf(&buff[76], "%2c",   cp->element[j]);   /* 17 76-77 2    LString(2)   element    Element symbol, right-just. */
         sscanf(&buff[78], "%2c",   cp->charge[j]);    /* 18 78-79 2    LString(2)   charge     Charge on the atom. */
-        
+
         //printf("%4d:%4d %d %d \'%s\'\n", i, j, cp->serial[j], cp->Hnum[j], cp->name[j]);
     }
 }
@@ -255,7 +279,7 @@ ScanPDBLine(char *buff, PDBCds *cp, int j)
 
 /* reads all coordinate fields for each model in a pdb file */
 int
-ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int fix_atom_names)
+ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int amber, int fix_atom_names)
 {
     //char            buff[99];
     int             bufflen = 256;
@@ -265,8 +289,8 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
     char            pdbdir[FILENAME_MAX], dirpdbfile_name[FILENAME_MAX];
     PDBCds     **cds = pdbA->cds;
     PDBCds      *cp = NULL;
-    
-    buff = malloc(bufflen* sizeof(char));
+
+    buff = calloc(bufflen, sizeof(char));
     if (buff == NULL)
     {
         perror("\n\n  ERROR");
@@ -274,7 +298,7 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
-    
+
     buff[bufflen-1] = '\0';
 
     pdbfile = fopen(pdbfile_name, "r");
@@ -286,7 +310,7 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
             strncpy(pdbdir, getenv("PDBDIR"), FILENAME_MAX);
             strncpy(dirpdbfile_name, pdbdir, FILENAME_MAX - 1);
             strncat(dirpdbfile_name, pdbfile_name, FILENAME_MAX - strlen(pdbfile_name) - 1);
-            
+
             pdbfile = fopen(dirpdbfile_name, "r");
         }
 
@@ -309,7 +333,7 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
         {
             while (fgets(buff, bufflen, pdbfile) != NULL)
             {
-                if (strncmp(buff, "MODEL", 5) == 0 || 
+                if (strncmp(buff, "MODEL", 5) == 0 ||
                     strncmp(buff, "REMARK FRAME:", 13) == 0 ||
                     strncmp(buff, "REMARK  OPLS-AA", 15) == 0) // DLTPU
                 {
@@ -333,11 +357,11 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
             }
 
             /* if the line is an ATOM or HETATM record */
-            if (strncmp(buff, "ATOM  ", 6) == 0 || 
+            if (strncmp(buff, "ATOM  ", 6) == 0 ||
                 strncmp(buff, "HETATM", 6) == 0)
             {
-                ScanPDBLine(buff, cp, j);
-                if (fix_atom_names == 0)
+                ScanPDBLine(buff, cp, j, amber);
+                if (fix_atom_names == 1)
                     XPLORcorrections(cp, j);
 
                 if (isfinite(cp->occupancy[j]) == 0)
@@ -361,28 +385,28 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
 //     int             vlen, slxnlen = 0;
 //     int            *selection_index = NULL; /* array of ints corresponding to selected atoms */
 //     int             i, lower, upper, pdbi;
-// 
+//
 //     if (pdbA->cnum < 2)
 //     {
 //         fprintf(stderr, "\n  ERROR23: Number of cds in pdbfiles is less than 2. \n");
 //         PrintTheseusTag();
 //         exit(EXIT_FAILURE);
 //     }
-// 
+//
 //     CdsArrayAllocNum(baseA, pdbA->cnum);
-// 
+//
 //     for (pdbi = 0; pdbi < pdbA->cnum; ++pdbi)
 //     {
 //         lower = 0;
 //         upper = vlen = pdbA->cds[pdbi]->vlen;
-//     
+//
 //         if (upper - 4 < lower)
 //         {
 //             fprintf(stderr, "\n  ERROR: upper residue bound must be at least 3 greater than the lower bound. \n");
 //             PrintTheseusTag();
 //             exit(EXIT_FAILURE);
 //         }
-//     
+//
 //         selection_index = (int *) malloc (vlen * sizeof(int));
 //         if (selection_index == NULL)
 //         {
@@ -391,7 +415,7 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
 //             PrintTheseusTag();
 //             exit(EXIT_FAILURE);
 //         }
-// 
+//
 //         slxnlen = 0;
 //         for (i = 0; i < vlen; ++i)
 //         {
@@ -406,13 +430,13 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
 //                 ++slxnlen;
 //             }
 //         }
-// 
+//
 //         baseA->cds[pdbi] = CdsInit();
 //         CdsAlloc(baseA->cds[pdbi], slxnlen);
-// 
+//
 //         baseA->cds[pdbi]->model = pdbA->cds[pdbi]->model;
 //         strcpy(baseA->cds[pdbi]->filename, pdbA->cds[pdbi]->filename);
-//     
+//
 //         for (i = 0; i < slxnlen; ++i)
 //         {
 //             strncpy(baseA->cds[pdbi]->resName[i], pdbA->cds[pdbi]->resName[selection_index[i]], 4);
@@ -423,16 +447,16 @@ ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int f
 //             baseA->cds[pdbi]->o[i]      = pdbA->cds[pdbi]->occupancy[selection_index[i]];
 //             baseA->cds[pdbi]->b[i]      = pdbA->cds[pdbi]->tempFactor[selection_index[i]];
 //         }
-//         
+//
 //         free(selection_index);
 //     }
-// 
+//
 //     baseA->vlen = slxnlen;
 //     baseA->avecds = CdsInit();
 //     CdsAlloc(baseA->avecds, slxnlen);
 //     /*PrintCds(baseA->cds[0]);
 //     PrintCds(baseA->cds[1]);*/
-// 
+//
 //     return (baseA);
 // }
 
@@ -460,8 +484,8 @@ GetSlxnLen(PDBCdsArray *pdbA, const int crds, Algorithm *algo, char *chains,
     int            i, vlen;
 
     vlen = 0;
-	for (i = 0; i < pdbA->cds[crds]->vlen; ++i)
-	{
+    for (i = 0; i < pdbA->cds[crds]->vlen; ++i)
+    {
 /*         printf("\n%s, %s, %c, %c, %d", */
 /*                pdbA->cds[crds]->record[i], */
 /*                pdbA->cds[crds]->name[i], */
@@ -469,17 +493,17 @@ GetSlxnLen(PDBCdsArray *pdbA, const int crds, Algorithm *algo, char *chains,
 /*                pdbA->cds[crds]->chainID[i], */
 /*                pdbA->cds[crds]->resSeq[i]); */
 /*         fflush(NULL); */
-		if (   (   strncmp(pdbA->cds[crds]->record[i], "ATOM  ", 6) == 0
-				|| strncmp(pdbA->cds[crds]->record[i], "HETATM", 6) == 0)
-			&& atom_selxn(pdbA->cds[crds]->name[i], algo->atoms, algo->atomslxn) == 1
-			&& (pdbA->cds[crds]->altLoc[i] == ' ' || pdbA->cds[crds]->altLoc[i] == 'A')
-			&& range_selxn(pdbA->cds[crds]->chainID[i], chains, pdbA->cds[crds]->resSeq[i], lower, upper, range_num) == rev) /* DLT debug FIX THIS!!!! */
-		{
-		    if (selection_index != NULL)
-    			selection_index[vlen] = i;
-			++vlen;
-		}
-	}
+        if (   (   strncmp(pdbA->cds[crds]->record[i], "ATOM  ", 6) == 0
+                || strncmp(pdbA->cds[crds]->record[i], "HETATM", 6) == 0)
+            && atom_selxn(pdbA->cds[crds]->name[i], algo->atoms, algo->atomslxn) == 1
+            && (pdbA->cds[crds]->altLoc[i] == ' ' || pdbA->cds[crds]->altLoc[i] == 'A')
+            && range_selxn(pdbA->cds[crds]->chainID[i], chains, pdbA->cds[crds]->resSeq[i], lower, upper, range_num) == rev) /* DLT debug FIX THIS!!!! */
+        {
+            if (selection_index != NULL)
+                selection_index[vlen] = i;
+            ++vlen;
+        }
+    }
 
     return(vlen);
 }
@@ -520,7 +544,7 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
             PrintTheseusTag();
             exit(EXIT_FAILURE);
         }
-        
+
         for (i = 0; i < range_num; ++i)
         {
             selections[i] = (char *) calloc(128, sizeof(char));
@@ -530,7 +554,7 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
                 fprintf(stderr, "\n  ERROR1001: could not allocate memory for selections[] in GetCdsSelection(). \n");
                 PrintTheseusTag();
                 exit(EXIT_FAILURE);
-            }   
+            }
         }
 
         /* if the user specified XPLOR/CNS-style atoms, translate them to standard PDB format (DNA primes should be "*", not "'") */
@@ -539,7 +563,7 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
                 baseA->algo->selection[i] = '*';
 
         /* copy each range selection string into the 'selections[]' array */
-        mystrncpy(selections[0], strtok(baseA->algo->selection, delims), 127); 
+        mystrncpy(selections[0], strtok(baseA->algo->selection, delims), 127);
         for (i = 1; i < range_num; ++i)
             mystrncpy(selections[i], strtok(NULL, delims), 127);
 
@@ -573,14 +597,14 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
             if (isdigit(selections[j][i]))
             {
                 lower[j] = (int) strtol(&selections[j][i], endptr, 10);
-        
+
                 while(selections[j][i] != '-' && i < selection_len)
                     ++i;
-    
+
                 ++i;
                 while(isspace(selections[j][i]) && i < selection_len)
                     ++i;
-    
+
                 upper[j] = (int) strtol(&selections[j][i], endptr, 10);
             }
             else
@@ -639,26 +663,26 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
 //                pdbA->cds[i]->resSeq[i]);
 //         fflush(NULL);
         last_len = vlen;
-		if (baseA->algo->revsel == 0)
-			vlen = GetSlxnLen(pdbA, i, baseA->algo, chains, lower, upper, range_num, NULL, 1);
-		else
-			vlen = GetSlxnLen(pdbA, i, baseA->algo, chains, lower, upper, range_num, NULL, 0);
-	
-	    if (i > 0 && vlen != last_len)
-		{
-			fprintf(stderr,
-					"\n  ERROR1: length of selection is (%d) different from preceding cds (%d) in GetCdsSelection() \n", vlen, i+1);
-			PrintTheseusTag();
-			exit(EXIT_FAILURE);
-		}
+        if (baseA->algo->revsel == 0)
+            vlen = GetSlxnLen(pdbA, i, baseA->algo, chains, lower, upper, range_num, NULL, 1);
+        else
+            vlen = GetSlxnLen(pdbA, i, baseA->algo, chains, lower, upper, range_num, NULL, 0);
 
-		if (vlen < 3)
-		{
-			fprintf(stderr,
-					"\n  ERROR3: 'vlen' is too small (%d) in GetCdsSelection(); not enough atoms selected in cds %d. \n", vlen, i+1);
-			PrintTheseusTag();
-			exit(EXIT_FAILURE);
-		}
+        if (i > 0 && vlen != last_len)
+        {
+            fprintf(stderr,
+                    "\n  ERROR1: length of selection is (%d) different from preceding cds (%d) in GetCdsSelection() \n", vlen, i+1);
+            PrintTheseusTag();
+            exit(EXIT_FAILURE);
+        }
+
+        if (vlen < 3)
+        {
+            fprintf(stderr,
+                    "\n  ERROR3: 'vlen' is too small (%d) in GetCdsSelection(); not enough atoms selected in cds %d. \n", vlen, i+1);
+            PrintTheseusTag();
+            exit(EXIT_FAILURE);
+        }
     }
 
     /* Now allocate based on this length */
@@ -669,10 +693,10 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
     /* Now get the selections again and read them in this time */
     for (j = 0; j < pdbA->cnum; ++j)
     {
-		if (baseA->algo->revsel == 0)
-			vlen = GetSlxnLen(pdbA, j, baseA->algo, chains, lower, upper, range_num, selection_index, 1);
-		else
-			vlen = GetSlxnLen(pdbA, j, baseA->algo, chains, lower, upper, range_num, selection_index, 0);
+        if (baseA->algo->revsel == 0)
+            vlen = GetSlxnLen(pdbA, j, baseA->algo, chains, lower, upper, range_num, selection_index, 1);
+        else
+            vlen = GetSlxnLen(pdbA, j, baseA->algo, chains, lower, upper, range_num, selection_index, 0);
 
         baseA->cds[j]->model = pdbA->cds[j]->model;
         strncpy(baseA->cds[j]->filename, pdbA->cds[j]->filename, FILENAME_MAX - 1);
@@ -689,7 +713,7 @@ GetCdsSelection(CdsArray *baseA, PDBCdsArray *pdbA)
             baseA->cds[j]->b[i]      = pdbA->cds[j]->tempFactor[selection_index[i]];
         }
     }
-    
+
 /* PrintCds(baseA->cds[0]); */
 /* PrintCds(baseA->cds[1]); */
 
@@ -739,7 +763,7 @@ GetCdsSelection_old(CdsArray *baseA, PDBCdsArray *pdbA)
             PrintTheseusTag();
             exit(EXIT_FAILURE);
         }
-        
+
         for (i = 0; i < range_num; ++i)
         {
             selections[i] = (char *) calloc(128, sizeof(char));
@@ -749,7 +773,7 @@ GetCdsSelection_old(CdsArray *baseA, PDBCdsArray *pdbA)
                 fprintf(stderr, "\n  ERROR1001: could not allocate memory for selections[] in GetCdsSelection(). \n");
                 PrintTheseusTag();
                 exit(EXIT_FAILURE);
-            }   
+            }
         }
 
         /* if the user specified XPLOR/CNS-style atoms, translate them to standard PDB format (DNA primes should be "*", not "'") */
@@ -758,7 +782,7 @@ GetCdsSelection_old(CdsArray *baseA, PDBCdsArray *pdbA)
                 baseA->algo->selection[i] = '*';
 
         /* copy each range selection string into the 'selections[]' array */
-        mystrncpy(selections[0], strtok(baseA->algo->selection, delims), 127); 
+        mystrncpy(selections[0], strtok(baseA->algo->selection, delims), 127);
         for (i = 1; i < range_num; ++i)
             mystrncpy(selections[i], strtok(NULL, delims), 127);
 
@@ -792,14 +816,14 @@ GetCdsSelection_old(CdsArray *baseA, PDBCdsArray *pdbA)
             if (isdigit(selections[j][i]))
             {
                 lower[j] = (int) strtol(&selections[j][i], endptr, 10);
-        
+
                 while(selections[j][i] != '-' && i < selection_len)
                     ++i;
-    
+
                 ++i;
                 while(isspace(selections[j][i]) && i < selection_len)
                     ++i;
-    
+
                 upper[j] = (int) strtol(&selections[j][i], endptr, 10);
             }
             else
@@ -923,7 +947,7 @@ GetCdsSelection_old(CdsArray *baseA, PDBCdsArray *pdbA)
             baseA->cds[j]->b[i]      = pdbA->cds[j]->tempFactor[selection_index[i]];
         }
     }
-    
+
 /* PrintCds(baseA->cds[0]); */
 /* PrintCds(baseA->cds[1]); */
 
@@ -941,7 +965,7 @@ GetCdsSelection_old(CdsArray *baseA, PDBCdsArray *pdbA)
 
 
 PDBCdsArray
-*GetPDBCds(char **argv_array, int narguments, int fmodel, int fix_atom_names)
+*GetPDBCds(char **argv_array, int narguments, int fmodel, int amber, int fix_atom_names)
 {
     int                  i, j, k;
     int                 *models_per_pdb = NULL;
@@ -980,7 +1004,7 @@ PDBCdsArray
         {
             strncpy(dirpdbfile_name, pdbdir, FILENAME_MAX - 1);
             strncat(dirpdbfile_name, pdbfile_name, FILENAME_MAX - strlen(pdbfile_name) - 1);
-            
+
             pdbfile = fopen(dirpdbfile_name, "r");
 
             if (pdbfile == NULL)
@@ -996,7 +1020,7 @@ PDBCdsArray
         last_vlen = 0;
         while (fgets(buff, (int) sizeof(buff), pdbfile) != NULL)
         {
-            if (strncmp(buff, "MODEL", 5) == 0 || 
+            if (strncmp(buff, "MODEL", 5) == 0 ||
                 strncmp(buff, "REMARK FRAME:", 13) == 0 ||
                 strncmp(buff, "REMARK  OPLS-AA", 15) == 0) // DLTPU
             {
@@ -1067,7 +1091,7 @@ PDBCdsArray
 
         if (vlen < 3)
         {
-            fprintf(stderr, "\n  ERROR_002: 'vlen' is too small (%d) in GetPDBCds()", vlen); 
+            fprintf(stderr, "\n  ERROR_002: 'vlen' is too small (%d) in GetPDBCds()", vlen);
             fprintf(stderr, "\n  Too few atoms read. \n");
             PrintTheseusTag();
             exit(EXIT_FAILURE);
@@ -1095,7 +1119,7 @@ PDBCdsArray
     for (i = 0, j = 0; i < narguments && j < cnum; ++i)
     {
         strncpy(pdbfile_name, argv_array[i], FILENAME_MAX - 1);
-        ReadPDBCds(pdbfile_name, pdbA, j, models_per_pdb[i], fix_atom_names);
+        ReadPDBCds(pdbfile_name, pdbA, j, models_per_pdb[i], amber, fix_atom_names);
         j += models_per_pdb[i];
     }
 
@@ -1163,12 +1187,12 @@ PrintPDBCds(FILE *pdbfile, PDBCds *pdbcds)
         /* first expression evaluates whether at end of internal ATOM chain */
         /* second expression evaluates if at end of cds and ATOM chain */
         if (
-            ((i + 1) <  pdbcds->vlen && 
+            ((i + 1) <  pdbcds->vlen &&
               ( strncmp(pdbcds->record[i], "ATOM  ", 6) == 0 || strncmp(pdbcds->record[i], "HETATM", 6) == 0 )
             &&
              (pdbcds->chainID[i] != pdbcds->chainID[i+1] || pdbcds->xchainID[i] != pdbcds->xchainID[i+1]))
            ||
-            ((i + 1) == pdbcds->vlen && 
+            ((i + 1) == pdbcds->vlen &&
              ( strncmp(pdbcds->record[i], "ATOM  ", 6) == 0 || strncmp(pdbcds->record[i], "HETATM", 6) == 0 ))
            ||
             (i < pdbcds->vlen - 1 &&
@@ -1267,18 +1291,18 @@ PrintOccPDBCds(FILE *pdbfile, PDBCds *pdbcds)
                     pdbcds->segID[i],    pdbcds->element[i],   pdbcds->charge[i]);
             /* fflush(NULL); */
             ++serial;
-    
+
             /* add TER cards at end of ATOM chains */
             /* first expression evaluates whether at end of internal ATOM chain */
             /* second expression evaluates if at end of cds and ATOM chain */
             if (
-                ((i + 1) <  pdbcds->vlen && 
+                ((i + 1) <  pdbcds->vlen &&
                  ( strncmp(pdbcds->record[i], "ATOM  ", 6) == 0 || strncmp(pdbcds->record[i], "HETATM", 6) == 0 )
                 &&
                  (pdbcds->chainID[i] != pdbcds->chainID[i+1] || pdbcds->xchainID[i] != pdbcds->xchainID[i+1]))
                ||
-                ((i + 1) == pdbcds->vlen 
-                && 
+                ((i + 1) == pdbcds->vlen
+                &&
                 ( strncmp(pdbcds->record[i], "ATOM  ", 6) == 0 || strncmp(pdbcds->record[i], "HETATM", 6) == 0))
                ||
                 (i < pdbcds->vlen - 1 &&
@@ -1321,7 +1345,7 @@ IsNameCAorP(char *name)
 //     int             i = 0;
 //     int             ncoord;
 //     FILE           *pdbfile = NULL;
-// 
+//
 //     pdbfile = fopen(pdbfile_name, "r");
 //     if (pdbfile == NULL)
 //     {
@@ -1329,7 +1353,7 @@ IsNameCAorP(char *name)
 //         PrintTheseusTag();
 //         exit(EXIT_FAILURE);
 //     }
-// 
+//
 //     if (cdsA->cds[cds_index]->vlen == 0)
 //     {
 //         while (fgets(buff, sizeof(buff), pdbfile))
@@ -1337,7 +1361,7 @@ IsNameCAorP(char *name)
 //             if (strncmp(buff, "ENDMDL", 6) == 0 ||
 //                 strncmp(buff, "END   ", 6) == 0)
 //                 break;
-//     
+//
 //             if (!strncmp(buff, "ATOM  ", 6)
 //                 && (   strncmp(&buff[13], "CA ", 3) == 0
 //                     || strncmp(&buff[13], "P  ", 3) == 0))
@@ -1345,13 +1369,13 @@ IsNameCAorP(char *name)
 //                 alt = buff[16];     /* alternate position indicator */
 //                 if (alt == ' ' || alt == 'A' || alt == '1' || alt == 'L' || alt == 'O')
 //                     ++i;
-//             }    
+//             }
 //         }
-// 
+//
 //         cdsA->vlen = i;
 //         rewind(pdbfile);
 //     }
-// 
+//
 //     for (i = 0; i < modelnum; ++i)
 //     {
 //         /* move to next model */
@@ -1363,7 +1387,7 @@ IsNameCAorP(char *name)
 //                 break;
 //             }
 //         }
-// 
+//
 //         /* read in the model's cds */
 //         ncoord = 0;
 //         while (fgets(buff, sizeof(buff), pdbfile))
@@ -1371,7 +1395,7 @@ IsNameCAorP(char *name)
 //             if (!strncmp(buff, "ENDMDL", 6) ||
 //                 !strncmp(buff, "END   ", 6))
 //                 break;
-// 
+//
 //             if (!strncmp(buff, "ATOM  ", 6) &&
 //                 (!strncmp(&buff[13], "CA ", 3) ||
 //                  /*!strncmp(&buff[13], "CB ", 3) ||*/
@@ -1389,13 +1413,13 @@ IsNameCAorP(char *name)
 //                            &cdsA->cds[cds_index + i]->z[ncoord],
 //                            &cdsA->cds[cds_index + i]->o[ncoord],
 //                            &cdsA->cds[cds_index + i]->b[ncoord]);
-//     
+//
 //                     ncoord++;
 //                 }
 //             }
 //         }
 //     }
-// 
+//
 //     fclose(pdbfile);
 //     return (EXIT_SUCCESS);
 // }
@@ -1439,7 +1463,7 @@ WriteTheseusModelFile(PDBCdsArray *pdbA, Algorithm *algo, Statistics *stats, cha
     int             i;
 
     /* ////////////////////////////////////////////////////////////// */
-    
+
 /*     pdbfile = fopen(outfile_name, "w"); */
 /*     if (pdbfile ==NULL) */
 /*     { */
@@ -1482,7 +1506,7 @@ WriteTheseusModelFileNoStats(PDBCdsArray *pdbA, Algorithm *algo, char *outfile_n
     int             i;
 
     /* ////////////////////////////////////////////////////////////// */
-    
+
 /*     pdbfile = fopen(outfile_name, "w"); */
 /*     if (pdbfile ==NULL) */
 /*     { */
@@ -1815,7 +1839,7 @@ PDBCdsArray
     char            bincheck[14];
 
     fp = fopen(filename, "rb");
- 
+
     if (fp == NULL)
     {
         perror("\n  ERROR");
