@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2009 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "pdbMalloc.h"
 
 int
-ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int fix_atom_names);
+ReadPDBCds(char *pdbfile_name, PDBCdsArray *pdbA, int cds_i, int modelnum, int amber, int fix_atom_names);
 
 /* void */
 /* XPLORcorrections(PDBCds *pdbcds, int record); */
@@ -50,7 +50,7 @@ CdsArray
 /* range_selxn(int chainID, char *chains, int resSeq, int *lower, int *upper, int range_num); */
 
 PDBCdsArray
-*GetPDBCds(char **argv_array, int narguments, int fmodel, int fix_atom_names);
+*GetPDBCds(char **argv_array, int narguments, int fmodel, int amber, int fix_atom_names);
 
 void
 PrintCds(Cds *cds);
