@@ -1,7 +1,7 @@
 /*
     Theseus - maximum likelihood superpositioning of macromolecular structures
 
-    Copyright (C) 2004-2010 Douglas L. Theobald
+    Copyright (C) 2004-2013 Douglas L. Theobald
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -69,8 +69,8 @@ Seq2pdbAlloc(Seq2PDB *seq2pdb, const int seqnum)
     seq2pdb->map = (int *) calloc(seqnum, sizeof(int));
 
     /* allocate space for the fields in total */
-    seq2pdb->pdbfile_name_space = (char *) malloc(FILENAME_MAX * seqnum * sizeof(char));
-    seq2pdb->seqname_space = (char *) malloc(128 * seqnum * sizeof(char));
+    seq2pdb->pdbfile_name_space = (char *) calloc(FILENAME_MAX * seqnum, sizeof(char));
+    seq2pdb->seqname_space = (char *) calloc(128 * seqnum, sizeof(char));
 
     if (   seq2pdb->pdbfile_name == NULL
         || seq2pdb->pdbfile_name == NULL)
@@ -213,6 +213,7 @@ Algorithm
     algo->instfile     = 0;
     algo->pu           = 0;
     algo->FragDist     = 0;
+    algo->amber        = 0;
     algo->atom_names   = 0;
     algo->scalefactor  = 1.0;
 
@@ -510,7 +511,7 @@ void
 PCAAlloc(CdsArray *cdsA)
 {
     cdsA->pcamat = MatAlloc(cdsA->vlen, cdsA->vlen);
-    cdsA->pcavals = malloc(cdsA->vlen * sizeof(double));
+    cdsA->pcavals = calloc(cdsA->vlen, sizeof(double));
 }
 
 
