@@ -79,18 +79,18 @@ CopyStats(CdsArray *cdsA1, CdsArray *cdsA2)
     }
 
     CdsCopyAll(cdsA1->avecds, cdsA2->avecds);
-    
+
     if (cdsA2->algo->pca > 0 && cdsA2->pcamat != NULL)
     {
         if (cdsA1->pcamat != NULL)
             MatDestroy(&cdsA1->pcamat);
-    
+
         if (cdsA1->pcavals != NULL)
             free(cdsA1->pcavals);
-    
+
         cdsA1->pcamat = MatAlloc(cdsA2->algo->pca, vlen);
         cdsA1->pcavals = malloc(vlen * sizeof(double));
-        
+
         memcpy(cdsA1->pcamat[0], cdsA2->pcamat[0], cdsA2->algo->pca * vlen * sizeof(double));
         memcpy(cdsA1->pcavals, cdsA2->pcavals, vlen * sizeof(double));
     }
@@ -102,13 +102,13 @@ CalcDf(CdsArray *cdsA)
 {
     int         i,j;
 
-	for (i = 0; i < cdsA->vlen; ++i)
-	{
-		cdsA->df[i] = 0;
-		for (j = 0; j < cdsA->cnum; ++j)
-			cdsA->df[i] += cdsA->cds[j]->o[i];
+    for (i = 0; i < cdsA->vlen; ++i)
+    {
+        cdsA->df[i] = 0;
+        for (j = 0; j < cdsA->cnum; ++j)
+            cdsA->df[i] += cdsA->cds[j]->o[i];
 
-		//cdsA->df[i] *= 3;
+        //cdsA->df[i] *= 3;
     }
 }
 
@@ -179,15 +179,15 @@ VarianceCds(CdsArray *cdsA)
     {
         cdsj = (Cds *) cds[j];
 
-		for (i = 0; i < vlen; ++i)
-		{
-			tmpx = cdsj->x[i] - avex[i];
-			var[i] += tmpx * tmpx;
-			tmpy = cdsj->y[i] - avey[i];
-			var[i] += tmpy * tmpy;
-			tmpz = cdsj->z[i] - avez[i];
-			var[i] += tmpz * tmpz;
-		}
+        for (i = 0; i < vlen; ++i)
+        {
+            tmpx = cdsj->x[i] - avex[i];
+            var[i] += tmpx * tmpx;
+            tmpy = cdsj->y[i] - avey[i];
+            var[i] += tmpy * tmpy;
+            tmpz = cdsj->z[i] - avez[i];
+            var[i] += tmpz * tmpz;
+        }
     }
 
     for (i = 0; i < vlen; ++i)
@@ -282,15 +282,15 @@ VarianceCdsOcc(CdsArray *cdsA)
 /*     { */
 /*         cdsj = (Cds *) cds[j]; */
 /*  */
-/* 		for (j = 0; j < cnum; ++j) */
-/* 		{ */
-/* 			tmpx = cdsj->x[i] - avex[i]; */
-/* 			var[i] += tmpx * tmpx; */
-/* 			tmpy = cdsj->y[i] - avey[i]; */
-/* 			var[i] += tmpy * tmpy; */
-/* 			tmpz = cdsj->z[i] - avez[i]; */
-/* 			var[i] += tmpz * tmpz; */
-/* 		} */
+/*      for (j = 0; j < cnum; ++j) */
+/*      { */
+/*          tmpx = cdsj->x[i] - avex[i]; */
+/*          var[i] += tmpx * tmpx; */
+/*          tmpy = cdsj->y[i] - avey[i]; */
+/*          var[i] += tmpy * tmpy; */
+/*          tmpz = cdsj->z[i] - avez[i]; */
+/*          var[i] += tmpz * tmpz; */
+/*      } */
 /*     } */
 /*  */
 /*     return(cdsA->stats->stddev); */
@@ -315,23 +315,23 @@ VarianceCdsOcc(CdsArray *cdsA)
 /*  */
 /*     fprintf(transfile, "# Translation vectors\n"); */
 /*  */
-/* 	for (i = 0; i < cdsA->cnum; ++i) */
-/* 	{ */
-/* 		fprintf(transfile, */
-/* 		        "MODEL %3d, t: %9.4f %9.4f %9.4f\n", */
-/* 		        i+1, */
-/* 			    cdsA->cds[i]->translation[0], */
-/* 			    cdsA->cds[i]->translation[1], */
-/* 			    cdsA->cds[i]->translation[2]); */
-/* 	} */
+/*  for (i = 0; i < cdsA->cnum; ++i) */
+/*  { */
+/*      fprintf(transfile, */
+/*              "MODEL %3d, t: %9.4f %9.4f %9.4f\n", */
+/*              i+1, */
+/*              cdsA->cds[i]->translation[0], */
+/*              cdsA->cds[i]->translation[1], */
+/*              cdsA->cds[i]->translation[2]); */
+/*  } */
 /*  */
 /*     fprintf(transfile, "\n# Rotation matrices\n"); */
 /*  */
-/* 	for (i = 0; i < cdsA->cnum; ++i) */
-/* 	{ */
-/* 		fprintf(transfile, "MODEL %3d, R: ", i+1); */
+/*  for (i = 0; i < cdsA->cnum; ++i) */
+/*  { */
+/*      fprintf(transfile, "MODEL %3d, R: ", i+1); */
 /*  */
-/* 		for (j = 0; j < 3; ++j) */
+/*      for (j = 0; j < 3; ++j) */
 /*         { */
 /*             fprintf(transfile, */
 /*                     "% 10.7f % 10.7f % 10.7f    ", */
@@ -341,10 +341,10 @@ VarianceCdsOcc(CdsArray *cdsA)
 /*         } */
 /*  */
 /*         fputc('\n', transfile); */
-/* 	} */
+/*  } */
 /*  */
 /*     fprintf(transfile, "\n\n"); */
-/* 	fflush(NULL); */
+/*  fflush(NULL); */
 /*  */
 /*     fclose(transfile); */
 /* } */
@@ -369,23 +369,23 @@ WriteTransformations(CdsArray *cdsA, char *outfile_name)
 
     fprintf(transfile, "# Translation vectors\n");
 
-	for (i = 0; i < cdsA->cnum; ++i)
-	{
-		fprintf(transfile,
-		        "MODEL %3d, t: %9.4f %9.4f %9.4f\n",
-		        i+1,
-			    cdsA->cds[i]->translation[0],
-			    cdsA->cds[i]->translation[1],
-			    cdsA->cds[i]->translation[2]);
-	}
+    for (i = 0; i < cdsA->cnum; ++i)
+    {
+        fprintf(transfile,
+                "MODEL %3d, t: %9.4f %9.4f %9.4f\n",
+                i+1,
+                cdsA->cds[i]->translation[0],
+                cdsA->cds[i]->translation[1],
+                cdsA->cds[i]->translation[2]);
+    }
 
     fprintf(transfile, "\n# Rotation matrices\n");
 
-	for (i = 0; i < cdsA->cnum; ++i)
-	{
-		fprintf(transfile, "MODEL %3d, R: ", i+1);
+    for (i = 0; i < cdsA->cnum; ++i)
+    {
+        fprintf(transfile, "MODEL %3d, R: ", i+1);
 
-		for (j = 0; j < 3; ++j)
+        for (j = 0; j < 3; ++j)
         {
             fprintf(transfile,
                     "% 10.7f % 10.7f % 10.7f    ",
@@ -395,21 +395,21 @@ WriteTransformations(CdsArray *cdsA, char *outfile_name)
         }
 
         fputc('\n', transfile);
-	}
+    }
 
     fprintf(transfile, "\n# Rotations, angle-axis representation\n");
 
-	for (i = 0; i < cdsA->cnum; ++i)
-	{
-	    angle = RotMat2AxisAngle(cdsA->cds[i]->matrix, v);
+    for (i = 0; i < cdsA->cnum; ++i)
+    {
+        angle = RotMat2AxisAngle(cdsA->cds[i]->matrix, v);
 
-		fprintf(transfile,
-		        "MODEL %3d, Angle: % 10.7f  Axis: % 10.7f % 10.7f % 10.7f\n",
-		        i+1, angle, v[0], v[1], v[2]);
-	}
+        fprintf(transfile,
+                "MODEL %3d, Angle: % 10.7f  Axis: % 10.7f % 10.7f % 10.7f\n",
+                i+1, angle, v[0], v[1], v[2]);
+    }
 
     fprintf(transfile, "\n\n");
-	fflush(NULL);
+    fflush(NULL);
 
     free(v);
     fclose(transfile);
@@ -472,53 +472,53 @@ WriteVariance(CdsArray *cdsA, char *outfile_name)
 
     if (cdsA->algo->varweight == 1 || cdsA->algo->leastsquares == 1)
     {
-		for (i = 0; i < cdsA->vlen; ++i)
-		{
-		    dfi = cdsA->df[i];
-		    //rmsd = CalcResRMSD(cdsA, i);
-		    /* we have to factor in the fact that RMSD is over all axes,
-		       whereas my variance is *per* axis (must multiple variance
-		       by a factor of 3) */
-		    rmsd = sqrt(cdsA->var[i] * 6.0 * dfi / (dfi - 1));
+        for (i = 0; i < cdsA->vlen; ++i)
+        {
+            dfi = cdsA->df[i];
+            //rmsd = CalcResRMSD(cdsA, i);
+            /* we have to factor in the fact that RMSD is over all axes,
+               whereas my variance is *per* axis (must multiple variance
+               by a factor of 3) */
+            rmsd = sqrt(cdsA->var[i] * 6.0 * dfi / (dfi - 1));
 
-			fprintf(varfile,
-					"RES %-5d       %3s %6d %12.6f %12.6f %12.6f",
-					i+1,
-					cdsA->cds[0]->resName[i],
-					cdsA->cds[0]->resSeq[i],
-					cdsA->var[i],
-					sqrt(cdsA->var[i]),
-					rmsd);
-					
-		    notcore = 0;
-		    for (j=0; j < cdsA->cnum; ++j)
-		        if (cdsA->cds[j]->o[i] == 0)
-		            notcore = 1;
-		    
-		    if (notcore == 0)
-		        fprintf(varfile, " CORE\n");
-		    else
-		        fprintf(varfile, "\n");
-		}
+            fprintf(varfile,
+                    "RES %-5d       %3s %6d %12.6f %12.6f %12.6f",
+                    i+1,
+                    cdsA->cds[0]->resName[i],
+                    cdsA->cds[0]->resSeq[i],
+                    cdsA->var[i],
+                    sqrt(cdsA->var[i]),
+                    rmsd);
+
+            notcore = 0;
+            for (j=0; j < cdsA->cnum; ++j)
+                if (cdsA->cds[j]->o[i] == 0)
+                    notcore = 1;
+
+            if (notcore == 0)
+                fprintf(varfile, " CORE\n");
+            else
+                fprintf(varfile, "\n");
+        }
     }
     else if (cdsA->algo->covweight == 1)
     {
-		for (i = 0; i < cdsA->vlen; ++i)
-		{
-		    dfi = cdsA->df[i];
-			fprintf(varfile,
-					"RES %-5d      %3s %6d %12.6f %12.6f %12.6f\n",
-					i+1,
-					cdsA->cds[0]->resName[i],
-					cdsA->cds[0]->resSeq[i],
-					cdsA->CovMat[i][i],
-					sqrt(cdsA->CovMat[i][i]),
-					sqrt(6.0 * cdsA->CovMat[i][i] * dfi / (dfi - 1)));
-		}
+        for (i = 0; i < cdsA->vlen; ++i)
+        {
+            dfi = cdsA->df[i];
+            fprintf(varfile,
+                    "RES %-5d      %3s %6d %12.6f %12.6f %12.6f\n",
+                    i+1,
+                    cdsA->cds[0]->resName[i],
+                    cdsA->cds[0]->resSeq[i],
+                    cdsA->CovMat[i][i],
+                    sqrt(cdsA->CovMat[i][i]),
+                    sqrt(6.0 * cdsA->CovMat[i][i] * dfi / (dfi - 1)));
+        }
     }
 
     fputc('\n', varfile);
-	fflush(NULL);
+    fflush(NULL);
 
     /* printf("\nVariance range: %f\n", log(VecBiggest(cdsA->var, cdsA->vlen)/VecSmallest(cdsA->var, cdsA->vlen))/log(10.0)); */
 
@@ -532,12 +532,12 @@ Vars2Bfacts(CdsArray *cdsA)
     int         i;
     double      bfact = 8.0 * MY_PI * MY_PI;
 
-	for (i = 0; i < cdsA->vlen; ++i)
-	{
-		 cdsA->avecds->b[i] = cdsA->var[i] * bfact;
+    for (i = 0; i < cdsA->vlen; ++i)
+    {
+         cdsA->avecds->b[i] = cdsA->var[i] * bfact;
 
-		 if (cdsA->avecds->b[i] > 99.99)
-			 cdsA->avecds->b[i] = 99.99;
+         if (cdsA->avecds->b[i] > 99.99)
+             cdsA->avecds->b[i] = 99.99;
     }
 }
 
@@ -548,8 +548,8 @@ Bfacts2PrVars(CdsArray *cdsA, int coord)
     int         i;
     double      bfact = 1.0 / (24.0 * MY_PI * MY_PI);
 
-	for (i = 0; i < cdsA->vlen; ++i)
-		cdsA->cds[coord]->prvar[i] = cdsA->cds[coord]->b[i] * bfact;
+    for (i = 0; i < cdsA->vlen; ++i)
+        cdsA->cds[coord]->prvar[i] = cdsA->cds[coord]->b[i] * bfact;
 
     for (i = 0; i < cdsA->vlen; ++i)
     {
@@ -561,8 +561,8 @@ Bfacts2PrVars(CdsArray *cdsA, int coord)
 
 
 /* average of all possible unique pairwise RMSDs */
-/* Eqn 1 and following paragraph, Kearsley, S.K. (1990) "An algorithm for the 
-   simultaneous superposition of a structural series." Journal of Computational 
+/* Eqn 1 and following paragraph, Kearsley, S.K. (1990) "An algorithm for the
+   simultaneous superposition of a structural series." Journal of Computational
    Chemistry 11(10):1187-1192. */
 /* double */
 /* CalcPRMSD(CdsArray *cdsA) */
@@ -603,8 +603,8 @@ Bfacts2PrVars(CdsArray *cdsA, int coord)
 
 
 /* average of all possible unique pairwise RMSDs */
-/* Eqn 1 and following paragraph, Kearsley, S.K. (1990) "An algorithm for the 
-   simultaneous superposition of a structural series." Journal of Computational 
+/* Eqn 1 and following paragraph, Kearsley, S.K. (1990) "An algorithm for the
+   simultaneous superposition of a structural series." Journal of Computational
    Chemistry 11(10):1187-1192. */
 double
 CalcPRMSD_old(CdsArray *cdsA)
@@ -643,7 +643,7 @@ CalcPRMSD_old(CdsArray *cdsA)
 
 //    paRMSD  = (2.0 *  sqrdist) / (double) (vlen * cnum * (cnum - 1));
 //    printf("\npaRMSD = %8.3e\n", sqrt(paRMSD));
-    paRMSD  = sqrdist / wtsum; 
+    paRMSD  = sqrdist / wtsum;
 //    printf("\npaRMSD = %8.3e\n", sqrt(paRMSD));
     //pawRMSD = (2.0 * wsqrdist) / (double) (vlen * cnum * (cnum - 1));
     pawRMSD = wsqrdist / wtsum;
@@ -658,35 +658,36 @@ double
 CalcPRMSD(CdsArray *cdsA)
 {
     int             i, j, k, cnt;
-    double          sqrdist, scd, x;
+    double          sqrdist, x;
     double          wsqrdist;
     double          wtsum;
     double          paRMSD, pawRMSD;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    const Cds   *cdsi, *cdsj;
+    const Cds     **cds = (const Cds **) cdsA->cds;
+    const Cds      *cdsi, *cdsj;
     const double   *w = (const double *) cdsA->w;
 
+
     sqrdist = wsqrdist = wtsum = 0.0;
 
     for (k = 0; k < vlen; ++k)
     {
-        scd = 0.0;
+        //scd = 0.0;
         cnt = 0;
         for (i = 0; i < cnum; ++i)
         {
             cdsi = cds[i];
-    
+
             if (cdsi->o[k] > 0)
             {
                 for (j = 0; j < i; ++j)
                 {
                     cdsj = cds[j];
-        
+
                     if (cdsj->o[k] > 0)
                     {
                         x = SqrCdsDist(cdsi, k, cdsj, k);
-                        scd += x;
+                        //scd += x;
                         wsqrdist += (w[k] * SqrCdsDist(cdsi, k, cdsj, k));
                         sqrdist += x;
                         wtsum++;
@@ -695,13 +696,13 @@ CalcPRMSD(CdsArray *cdsA)
                 }
             }
         }
-        
+
         //printf("rmsd[%4d]:% f\n", k, sqrt(scd / cnt));
     }
 
 //    paRMSD  = (2.0 *  sqrdist) / (double) (vlen * cnum * (cnum - 1));
 //    printf("\npaRMSD = %8.3e\n", sqrt(paRMSD));
-    paRMSD  = sqrdist / wtsum; 
+    paRMSD  = sqrdist / wtsum;
 //    printf("\npaRMSD = %8.3e\n", sqrt(paRMSD));
     //pawRMSD = (2.0 * wsqrdist) / (double) (vlen * cnum * (cnum - 1));
     pawRMSD = wsqrdist / wtsum;
@@ -712,73 +713,6 @@ CalcPRMSD(CdsArray *cdsA)
 }
 
 
-
-double
-CalcPRMSD_matt(CdsArray *cdsA)
-{
-    int             i, j, k;
-    double          sqrdist, x;
-    double          wsqrdist;
-    double          wtsum, sum, resnum;
-    double          paRMSD, pawRMSD;
-    const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const Cds  **cds = (const Cds **) cdsA->cds;
-    const Cds   *cdsi, *cdsj;
-    const double   *w = (const double *) cdsA->w;
-
-
-    sqrdist = wsqrdist = resnum = 0.0;
-	for (k = 0; k < vlen; ++k)
-	{
-	    wtsum = 0.0;
-	    sum = 0.0;
-		for (i = 0; i < cnum; ++i)
-		{
-			cdsi = cds[i];
-	        if (cdsi->o[k] > 0)
-	        {
-				for (j = 0; j < i; ++j)
-				{
-					cdsj = cds[j];
-		
-					if (cdsj->o[k] > 0)
-					{
-						x = SqrCdsDist(cdsi, k, cdsj, k);
-						wsqrdist += (w[k] * SqrCdsDist(cdsi, k, cdsj, k));
-						
-						if (x < 25.0)
-						{
-							sum += x;
-							wtsum++;
-							resnum++;
-						}
-						printf("%f %f %f\n", sum, sqrdist, resnum);
-					}
-					else
-					{
-						printf("NO i:%4d j:%4d k%4d\n", i, j, k);
-				    }
-				}
-			}
-		}
-
-        if (wtsum > 0.0)
-		    sqrdist += sum/wtsum;
-    }
-
-//    paRMSD  = (2.0 *  sqrdist) / (double) (vlen * cnum * (cnum - 1));
-//    printf("\npaRMSD = %8.3e\n", sqrt(paRMSD));
-    paRMSD  = sqrdist / resnum; 
-//    printf("\npaRMSD = %8.3e\n", sqrt(paRMSD));
-    //pawRMSD = (2.0 * wsqrdist) / (double) (vlen * cnum * (cnum - 1));
-    pawRMSD = wsqrdist / resnum;
-    cdsA->stats->ave_pawRMSD = sqrt(pawRMSD);
-    cdsA->stats->ave_paRMSD  = sqrt(paRMSD);
-
-    return (cdsA->stats->ave_paRMSD);
-}
-
-
 /* Calculate a matrix normal maximum likelihood RMSD,
    based on the traces of the inverse covariance matrices --
    this is an RMSD from the mean (a sigma value),
@@ -829,7 +763,7 @@ CalcMLRMSD(CdsArray *cdsA)
 
 double
 SqrCdsDist(const Cds *cds1, const int atom1,
-              const Cds *cds2, const int atom2)
+           const Cds *cds2, const int atom2)
 {
     double          tmpx, tmpy, tmpz;
 
@@ -869,11 +803,11 @@ SqrCdsDist(const Cds *cds1, const int atom1,
 
 double
 SqrCdsDistMahal2(const Cds *cds1, const int atom1,
-                    const Cds *cds2, const int atom2,
-                    const double weight)
+                 const Cds *cds2, const int atom2,
+                 const double weight)
 {
     return(weight * (mysquare(cds2->x[atom2] - cds1->x[atom1]) +
-                     mysquare(cds2->y[atom2] - cds1->y[atom1]) + 
+                     mysquare(cds2->y[atom2] - cds1->y[atom1]) +
                      mysquare(cds2->z[atom2] - cds1->z[atom1])));
 }
 
@@ -1106,7 +1040,7 @@ PrintResiduals(CdsArray *cdsA)
     for (i = 0; i < cdsA->cnum; ++i)
     {
         for (j = 0; j < cdsA->vlen; ++j)
-        {   
+        {
             fprintf(stderr, "\n%-3d %12.6f %12.6f %12.6f",
                     j+1,
                     cds[i]->residual_x[j],
@@ -1135,10 +1069,10 @@ WriteResiduals(CdsArray *cdsA, char *outfile_name)
 
     for (i = 0; i < cdsA->cnum * cdsA->vlen * 3; ++i)
     {
-		fprintf(residualfile,
-				"%-3d %12.6f\n",
-				i+1,
-				cdsA->residuals[i]);
+        fprintf(residualfile,
+                "%-3d %12.6f\n",
+                i+1,
+                cdsA->residuals[i]);
     }
     fputc('\n', residualfile);
 
@@ -1444,12 +1378,12 @@ CalcNormResiduals(CdsArray *cdsA)
 
             if (cdsm->o[k] == 1)
             {
-				normresid[j] = (cdsm->x[k] - avex[k]) * rootv;
-				++j;
-				normresid[j] = (cdsm->y[k] - avey[k]) * rootv;
-				++j;
-				normresid[j] = (cdsm->z[k] - avez[k]) * rootv;
-				++j;
+                normresid[j] = (cdsm->x[k] - avex[k]) * rootv;
+                ++j;
+                normresid[j] = (cdsm->y[k] - avey[k]) * rootv;
+                ++j;
+                normresid[j] = (cdsm->z[k] - avez[k]) * rootv;
+                ++j;
             }
         }
     }
@@ -1495,13 +1429,13 @@ CalcNormResidualsLS(CdsArray *cdsA)
             // printf("\n%4d %4d %f", k, m, cdsm->o[k]); fflush(NULL);
             if (cdsm->o[k] == 1)
             {
-				normresid[j] = (cdsm->x[k] - avex[k]);
-				++j;
-				normresid[j] = (cdsm->y[k] - avey[k]);
-				++j;
-				normresid[j] = (cdsm->z[k] - avez[k]);
-				++j;
-				// printf("\n%4d %f", j, normresid[j]); fflush(NULL);
+                normresid[j] = (cdsm->x[k] - avex[k]);
+                ++j;
+                normresid[j] = (cdsm->y[k] - avey[k]);
+                ++j;
+                normresid[j] = (cdsm->z[k] - avez[k]);
+                ++j;
+                // printf("\n%4d %f", j, normresid[j]); fflush(NULL);
             }
         }
     }
@@ -1667,37 +1601,37 @@ CalcHierarchLogL(CdsArray *cdsA)
                 b = stats->hierarch_p1;
                 c = stats->hierarch_p2;
 
-				memcpy(newvar, cdsA->var, vlen * sizeof(double));
-				qsort(newvar, vlen, sizeof(double), dblcmp_rev);
-				/* qsort-dblcmp_rev sorts big to small */
-				xn1 = newvar[vlen-4];
+                memcpy(newvar, cdsA->var, vlen * sizeof(double));
+                qsort(newvar, vlen, sizeof(double), dblcmp_rev);
+                /* qsort-dblcmp_rev sorts big to small */
+                xn1 = newvar[vlen-4];
 
                 logL = invgamma_logL(newvar, vlen-3, b, c);
                        //- b * ExpInvXn(xn1, b, c) - (1+c)*ExpLogXn(xn1, b, c)
                        //-c * log(b) - lgamma(c)
                        //+ log(invgamma_cdf(xn1, b, c));
 
-				free(newvar);
+                free(newvar);
 
-				return(logL);
-				/* return(dist_logL(invgamma_lnpdf, stats->hierarch_p1, stats->hierarch_p2, cdsA->var, cdsA->vlen - 3)); */
-				/* invgamma_fit(newvar, cdsA->vlen - 3, &stats->hierarch_p1, &stats->hierarch_p12, &logL); */
-				/* return(cdsA->vlen * invgamma_logL(stats->hierarch_p1, stats->hierarch_p2)); */
+                return(logL);
+                /* return(dist_logL(invgamma_lnpdf, stats->hierarch_p1, stats->hierarch_p2, cdsA->var, cdsA->vlen - 3)); */
+                /* invgamma_fit(newvar, cdsA->vlen - 3, &stats->hierarch_p1, &stats->hierarch_p12, &logL); */
+                /* return(cdsA->vlen * invgamma_logL(stats->hierarch_p1, stats->hierarch_p2)); */
             }
             else if (cdsA->algo->covweight != 0)
             {
-				double **evecs = cdsA->tmpmatKK2;
-				int newlen;
+                double **evecs = cdsA->tmpmatKK2;
+                int newlen;
 
-				if (vlen - 3 < nd - 6)
-					newlen = vlen - 3;
-				else
-					newlen = nd - 6;
+                if (vlen - 3 < nd - 6)
+                    newlen = vlen - 3;
+                else
+                    newlen = nd - 6;
 
-				eigenvalsym((const double **) cdsA->CovMat, cdsA->var, evecs, vlen);
-				logL = invgamma_logL(cdsA->var + vlen - newlen, newlen, stats->hierarch_p1, stats->hierarch_p2);
+                eigenvalsym((const double **) cdsA->CovMat, cdsA->var, evecs, vlen);
+                logL = invgamma_logL(cdsA->var + vlen - newlen, newlen, stats->hierarch_p1, stats->hierarch_p2);
 
-				return(logL);
+                return(logL);
             }
 
             break;
@@ -1709,30 +1643,30 @@ CalcHierarchLogL(CdsArray *cdsA)
             {
                 double *newvar = malloc(vlen * sizeof(double));
 
-				memcpy(newvar, cdsA->var, vlen * sizeof(double));
-				qsort(newvar, vlen, sizeof(double), dblcmp_rev);
-				logL = invgamma_logL(newvar, vlen - 3, stats->hierarch_p1, stats->hierarch_p2);
-				free(newvar);
+                memcpy(newvar, cdsA->var, vlen * sizeof(double));
+                qsort(newvar, vlen, sizeof(double), dblcmp_rev);
+                logL = invgamma_logL(newvar, vlen - 3, stats->hierarch_p1, stats->hierarch_p2);
+                free(newvar);
 
-				return(logL);
-				/* return(dist_logL(invgamma_lnpdf, stats->hierarch_p1, stats->hierarch_p2, cdsA->var, cdsA->vlen - 3)); */
-				/* invgamma_fit(newvar, cdsA->vlen - 3, &stats->hierarch_p1, &stats->hierarch_p12, &logL); */
-				/* return(cdsA->vlen * invgamma_logL(stats->hierarch_p1, stats->hierarch_p2)); */
+                return(logL);
+                /* return(dist_logL(invgamma_lnpdf, stats->hierarch_p1, stats->hierarch_p2, cdsA->var, cdsA->vlen - 3)); */
+                /* invgamma_fit(newvar, cdsA->vlen - 3, &stats->hierarch_p1, &stats->hierarch_p12, &logL); */
+                /* return(cdsA->vlen * invgamma_logL(stats->hierarch_p1, stats->hierarch_p2)); */
             }
             else if (cdsA->algo->covweight != 0)
             {
-				double **evecs = cdsA->tmpmatKK2;
-				int newlen;
+                double **evecs = cdsA->tmpmatKK2;
+                int newlen;
 
-				if (vlen - 3 < nd - 6)
-					newlen = vlen - 3;
-				else
-					newlen = nd - 6;
+                if (vlen - 3 < nd - 6)
+                    newlen = vlen - 3;
+                else
+                    newlen = nd - 6;
 
-				eigenvalsym((const double **) cdsA->CovMat, cdsA->var, evecs, vlen);
-				logL = invgamma_logL(cdsA->var + vlen - newlen, newlen, stats->hierarch_p1, stats->hierarch_p2);
+                eigenvalsym((const double **) cdsA->CovMat, cdsA->var, evecs, vlen);
+                logL = invgamma_logL(cdsA->var + vlen - newlen, newlen, stats->hierarch_p1, stats->hierarch_p2);
 
-				return(logL);
+                return(logL);
             }
 
             break;
@@ -1801,7 +1735,7 @@ CalcLogScaleJacob(CdsArray *cdsA)
    structural superposition.
 
      NOTA BENE: This function assumes that the variances, covariance matrices,
-     hierarchical model parameters, average coordinates, rotations, and 
+     hierarchical model parameters, average coordinates, rotations, and
      translations have all been pre-calculated. Even when not calculating the
      optimal ML rotations and translation transformations, the other parameters
      in general must be estimated iteratively, as described below.
@@ -1886,7 +1820,7 @@ CalcLogL(CdsArray *cdsA)
             frobterm = -ndk2;
         }
     }
-    
+
     if (algo->scale > 0)
         scales = CalcLogScaleJacob(cdsA);
     else
@@ -1902,10 +1836,10 @@ CalcLogL(CdsArray *cdsA)
 
 /* printf("\n _>_>_>_>_>_>_>_>_> Frobterm: %f, -NDK/2: %f", FrobTerm(cdsA), -ndk2); */
 
-    stats->logL = scales 
-                + frobterm 
-                - ndk2 * log(2.0*MY_PI) 
-                - 0.5 * nd * lndetrow 
+    stats->logL = scales
+                + frobterm
+                - ndk2 * log(2.0*MY_PI)
+                - 0.5 * nd * lndetrow
                 + igL;
 
     return(stats->logL);
@@ -1987,23 +1921,23 @@ CalcVar(CdsArray *cdsA)
        based upon current superposition, put in CovMat */
     for (i = 0; i < vlen; ++i)
     {
-		varsum = 0.0;
-		for (k = 0; k < cnum; ++k)
-		{
-			cdsk = cds[k];
+        varsum = 0.0;
+        for (k = 0; k < cnum; ++k)
+        {
+            cdsk = cds[k];
 
-			newx = cdsk->x[i] - avex[i];
-			newy = cdsk->y[i] - avey[i];
-			newz = cdsk->z[i] - avez[i];
+            newx = cdsk->x[i] - avex[i];
+            newy = cdsk->y[i] - avey[i];
+            newz = cdsk->z[i] - avez[i];
 
-			#ifdef FP_FAST_FMA
-			varsum += fma(newx, newx, fma(newy, newy, newz * newz));
-			#else
-			varsum += (newx * newx + newy * newy + newz * newz);
-			#endif
-		}
+            #ifdef FP_FAST_FMA
+            varsum += fma(newx, newx, fma(newy, newy, newz * newz));
+            #else
+            varsum += (newx * newx + newy * newy + newz * newz);
+            #endif
+        }
 
-		var[i] = varsum; /* sample variance, ML biased not n-1 definition */
+        var[i] = varsum; /* sample variance, ML biased not n-1 definition */
     }
 
     return(var);
@@ -2022,12 +1956,12 @@ CalcMgLogLCov(CdsArray *cdsA)
     int             i;
 
     term = 0.5 * (3.0 * cnum - vlen + 2.0);
-    
+
 /*     printf("\nterm:%g\n", term); */
 /*     fflush(NULL); */
 
     mglogl = MultivarLnGamma(vlen, term)
-           - 3.0 * cnum * log(M_PI) 
+           - 3.0 * cnum * log(M_PI)
            - 0.5 * vlen * (vlen - 1.0) * log(2.0)
            + 0.5 * log(psi);
 
@@ -2309,14 +2243,18 @@ CalcStats(CdsArray *incdsA)
     double        **lastmat = MatAlloc(3,3);
     CdsArray    *cdsA = NULL;
 
-    cdsA = CdsArrayInit();
-    CdsArrayAlloc(cdsA, cnum, vlen);
-    CdsArraySetup(cdsA);
-    CdsArrayCopy(cdsA, incdsA);
+//     cdsA = CdsArrayInit();
+//     CdsArrayAlloc(cdsA, cnum, vlen);
+//     CdsArraySetup(cdsA);
+//     CdsArrayCopy(cdsA, incdsA);
 
-    if (algo->covweight == 1)
-        SetupCovWeighting(cdsA);
-    else if (algo->pca > 0)
+    cdsA = incdsA;
+
+//     if (algo->covweight == 1)
+//         SetupCovWeighting(cdsA);
+//     else
+
+    if (algo->pca > 0)
         if (cdsA->CovMat == NULL)
             cdsA->CovMat = MatAlloc(vlen, vlen);
 
@@ -2331,25 +2269,25 @@ CalcStats(CdsArray *incdsA)
 
     if (algo->noave == 0)
     {
-		if (algo->alignment == 1)
-		{
-			AveCdsOcc(cdsA);
-			EM_MissingCds(cdsA);
-			//printf("\n\nAveCds\n");
-			//PrintCds(scratchA->avecds);
-		}
-		else
-		{
-			AveCds(cdsA);
-		}
+        if (algo->alignment == 1)
+        {
+            AveCdsOcc(cdsA);
+            EM_MissingCds(cdsA);
+            //printf("\n\nAveCds\n");
+            //PrintCds(scratchA->avecds);
+        }
+        else
+        {
+            AveCds(cdsA);
+        }
 
         if (algo->mbias == 1)
             UnbiasMean(cdsA);
     }
 
-	CalcCovariances(cdsA);
-	/* CheckVars(cdsA); */
-	CalcWts(cdsA);
+    CalcCovariances(cdsA);
+    /* CheckVars(cdsA); */
+    CalcWts(cdsA);
 
     /* CheckVars(cdsA); */
     if (algo->leastsquares == 1)
@@ -2383,8 +2321,8 @@ CalcStats(CdsArray *incdsA)
                                       vlen * cnum * 3 + vlen, 0);
 
     n = (double) vlen * cnum * 3;
-	cdsA->stats->SES = sqrt((6.0 * n * (n-1)) / ((n-2) * (n+1) * (n+3))); /* exact formulas */
-	cdsA->stats->SEK = sqrt((24.0 * n * (n-1) * (n-1)) / ((n-3) * (n-2) * (n+3) * (n+5)));
+    cdsA->stats->SES = sqrt((6.0 * n * (n-1)) / ((n-2) * (n+1) * (n+3))); /* exact formulas */
+    cdsA->stats->SEK = sqrt((24.0 * n * (n-1) * (n-1)) / ((n-3) * (n-2) * (n+3) * (n+5)));
 
     if (algo->write_file == 1)
     {
@@ -2475,12 +2413,12 @@ CalcStats(CdsArray *incdsA)
         }
     }
 
-    CopyStats(incdsA, cdsA);
+    // CopyStats(incdsA, cdsA);
 
     free(evals);
     MatDestroy(&rotmat);
     MatDestroy(&lastmat);
-    CdsArrayDestroy(&cdsA);
+    // CdsArrayDestroy(&cdsA);
 }
 
 
