@@ -16,7 +16,7 @@
  *                  dtheobald@gmail.com
  *                  dtheobald@brandeis.edu
  *
- *  Copyright:      Copyright (c) 2004-2010 Douglas L. Theobald
+ *  Copyright:      Copyright (c) 2004-2013 Douglas L. Theobald
  *
  *  THESEUS is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as 
@@ -50,7 +50,7 @@ const gsl_rng_type     *T;
 gsl_rng                *r2;
 
 
-#if defined(__APPLE__)
+#if 0 //defined(__APPLE__)
     #include <CoreServices/CoreServices.h>
     #include <time.h>
     #include <sys/time.h>
@@ -108,9 +108,9 @@ main(int argc, char *argv[])
     Statistics     *stats = NULL;
     char           *sup_name = NULL, *ave_name = NULL, *transf_name = NULL,
                    *rand_transf_name = NULL, *mean_ip_name = NULL, *sup_var_name = NULL;
-    #if !defined(__APPLE__)
+    //#if !defined(__APPLE__)
         clock_t          start_time, end_time;
-    #endif
+    //#endif
     //unsigned long   seed = (unsigned long) time(NULL);
 
     signal(SIGINT, leave);
@@ -168,7 +168,7 @@ main(int argc, char *argv[])
         {
             strcat(algo->rootname, "_rand");
             //printf("\nfmodel\n = %d", algo->fmodel);
-            pdbA = GetPDBCds(algo->infiles, algo->filenum, algo->fmodel, algo->atom_names);
+            pdbA = GetPDBCds(algo->infiles, algo->filenum, algo->fmodel, algo->amber, algo->atom_names);
 //             if (algo->fmodel == 1)
 //             {
 //                 pdbA = MakeRandPDBCds(algo->iterations, /* # coordinates/forms */
@@ -249,7 +249,7 @@ main(int argc, char *argv[])
             printf("    Reading %d pdb files ... \n", algo->filenum);
         fflush(NULL);
 
-        pdbA = GetPDBCds(algo->infiles, algo->filenum, algo->fmodel, algo->atom_names);
+        pdbA = GetPDBCds(algo->infiles, algo->filenum, algo->fmodel, algo->amber, algo->atom_names);
         /* PrintPDBCds(stdout, pdbA->cds[0]); */
     }
 
@@ -315,7 +315,7 @@ main(int argc, char *argv[])
 
     /* CalcPreStats(baseA); */
 
-    #if defined(__APPLE__)
+    #if 0 // defined(__APPLE__)
         start_time = seconds();
     #else
         start_time = clock();
@@ -340,7 +340,7 @@ main(int argc, char *argv[])
 
     if (algo->FragDist > 0)
     {
-        printf("    FUUUUCCCKKKK!!!!!!!!! %d \n", algo->FragDist);
+        printf("    FUN!!!!! %d \n", algo->FragDist);
         fflush(NULL);
         FragDistPu(baseA, algo->FragDist, 2, algo->pu);
     }
@@ -389,7 +389,7 @@ main(int argc, char *argv[])
         }
     }
 
-    #if defined(__APPLE__)
+    #if 0 //defined(__APPLE__)
         end_time = seconds();
         algo->milliseconds = (double) (end_time - start_time) / 0.001;
     #else
@@ -604,10 +604,70 @@ ParseCmdLine(int argc, char *argv[], CdsArray *bseA)
     }
 
     /*  */
-    while ((option = getopt(argc, argv, "a:A:b:B:cCd:D:e:EfFg:GhHi:Ij:Jk:K:lLm:M:nNo:Op:P:q:Q:r:R:s:S:tT:uUvVw:WxXyYz:Z0123:4:56789")) != -1)
+    int option_index = 0;
+    char short_options[] = "a:A:b:B:cCd:D:e:EfFg:GhHi:Ij:Jk:K:lLm:M:nNo:Op:P:q:Q:r:R:s:S:tT:uUvVw:WxXyYz:Z0123:4:56789";
+
+    struct option long_options[] =
+    {
+        {"add",          required_argument, 0,  0 },
+        {"delete",       required_argument, 0,  0 },
+        {"alignment",    required_argument, 0, 'A'},
+        {"amber",        no_argument,       0,  0 },
+        {"bayes",        required_argument, 0, 'b'},
+        {"covariance",   no_argument,       0, 'c'}, // this one is aliased to the short_option 'c'
+        {"fasta",        no_argument,       0, 'F'},
+        {"help",         no_argument,       0, 'h'},
+        {"info",         no_argument,       0, 'I'},
+        {"invselection", required_argument, 0, 'S'},
+        {"iterations",   required_argument, 0, 'i'},
+        {"leastsquares", no_argument,       0, 'l'},
+        {"mapfile",      required_argument, 0, 'M'},
+        {"notrans",      no_argument,       0,  0 },
+        {"orient",       required_argument, 0, 'o'},
+        {"pca",          required_argument, 0, 'P'},
+        {"precision",    required_argument, 0, 'p'},
+        {"rootname",     required_argument, 0, 'r'},
+        {"seed",         required_argument, 0, 'X'},
+        {"selection",    required_argument, 0, 's'},
+        {"verbose",      optional_argument, 0, 'W'},
+        {"version",      no_argument,       0, 'V'},
+        {0,              0,                 0,  0 } // required zero array
+    };
+
+    while ((option = getopt_long(argc, argv, short_options, long_options, &option_index)) != -1)
     {
         switch (option) /* See Algorithm structure in Cds.h for explanations of these flags/options */
         {
+            case 0:
+                if (strcmp(long_options[option_index].name, "add") == 0)
+                {
+                    printf("add with arg %s\n", optarg);
+                }
+                else if (strcmp(long_options[option_index].name, "delete") == 0)
+                {
+                    printf("delete with arg %s\n", optarg);
+                }
+                else if (strcmp(long_options[option_index].name, "notrans") == 0)
+                {
+                    algo->notrans = 1;
+                }
+                else if (strcmp(long_options[option_index].name, "amber") == 0)
+                {
+                    algo->amber = 1; /* for dealing with fugly AMBER8 PDB format, with atom in wrong column */
+                }
+                else if (strcmp(long_options[option_index].name, "bayes") == 0)
+                {
+                    algo->bayes = (int) strtol(optarg, NULL, 10);
+                }
+/* 
+                else
+                {
+                    printf("\n  Bad option '--%s' \n", long_options[option_index].name);
+                    Usage(0);
+                    exit(EXIT_FAILURE);
+                }
+ */
+                break;
             case '0': /* don't do translations */
                 algo->notrans = 1;
                 break;
